<?php /*

 Composr
 Copyright (c) Christopher Graham, 2004-2024

 See docs/LICENSE.md for full licensing information.

*/

/**
 * @license    http://opensource.org/licenses/cpal_1.0 Common Public Attribution License
 * @copyright  Christopher Graham
 * @package    cms_homesite_tracker
 */

/**
 * Hook class.
 */
class Hook_addon_registry_cms_homesite_tracker
{
    /**
     * Get a list of file permissions to set.
     *
     * @param  boolean $runtime Whether to include wildcards represented runtime-created chmoddable files
     * @return array File permissions to set
     */
    public function get_chmod_array(bool $runtime = false) : array
    {
        return [];
    }

    /**
     * Get the version of the software this addon is for (used in generating the TAR filename).
     *
     * @return float Version number
     */
    public function get_version() : float
    {
        return cms_version_number();
    }

    /**
     * Get the minimum required version of the website software needed to use this addon.
     *
     * @return float Minimum required website software version
     */
    public function get_min_cms_version() : float
    {
        return 11.0;
    }

    /**
     * Get the maximum compatible version of the website software to use this addon.
     *
     * @return ?float Maximum compatible website software version (null: no maximum version currently)
     */
    public function get_max_cms_version() : ?float
    {
        return null;
    }

    /**
     * Get the addon category.
     *
     * @return string The category
     */
    public function get_category() : string
    {
        return 'Development';
    }

    /**
     * Get the addon author.
     *
     * @return string The author
     */
    public function get_author() : string
    {
        return 'Chris Graham';
    }

    /**
     * Find other authors.
     *
     * @return array A list of co-authors that should be attributed
     */
    public function get_copyright_attribution() : array
    {
        return [
            'Incorporates MantisBT',
        ];
    }

    /**
     * Get the addon licence (one-line summary only).
     *
     * @return string The licence
     */
    public function get_licence() : string
    {
        return 'Licensed on the same terms as Composr / MantisBT under GPL';
    }

    /**
     * Get the description of the addon.
     *
     * @return string Description of the addon
     */
    public function get_description() : string
    {
        return 'The homesite issue tracker.';
    }

    /**
     * Get a list of tutorials that apply to this addon.
     *
     * @return array List of tutorials
     */
    public function get_applicable_tutorials() : array
    {
        return [];
    }

    /**
     * Get a mapping of dependency types.
     *
     * @return array A structure specifying dependency information
     */
    public function get_dependencies() : array
    {
        return [
            'requires' => [
                'tickets',
                'ecommerce',
                'points',
                'Conversr',
                //'core_all_icons',
                'cms_homesite',
            ],
            'recommends' => [
                'stats',
                'MySQL',
                'cms_release_build',
                'composr_tutorials',
            ],
            'conflicts_with' => [],
            'previously_in_addon' => ['composr_homesite_support_credits'],
        ];
    }

    /**
     * Explicitly say which icon should be used.
     *
     * @return URLPATH Icon
     */
    public function get_default_icon() : string
    {
        return 'themes/default/images/icons/admin/component.svg';
    }

    /**
     * Get a list of files that belong to this addon.
     *
     * @return array List of files
     */
    public function get_file_list() : array
    {
        return [
            'data_custom/tracker.php',
            'lang_custom/EN/tracker.ini',
            'site/pages/modules_custom/tracker.php',
            'sources_custom/hooks/systems/addon_registry/cms_homesite_tracker.php',
            'sources_custom/hooks/systems/symbols/MANTIS_TOTAL.php',
            'sources_custom/hooks/systems/symbols/MANTIS_WEEK_ACTIVITY.php',
            'sources_custom/mantis.php',
            'sources_custom/miniblocks/main_mantis_tracker.php',
            'themes/default/css_custom/tracker.css',
            'themes/default/images_custom/icons/tracker/easy.svg',
            'themes/default/images_custom/icons/tracker/hard.svg',
            'themes/default/images_custom/icons/tracker/index.html',
            'themes/default/images_custom/icons/tracker/minus.svg',
            'themes/default/images_custom/icons/tracker/plus.svg',
            'themes/default/images_custom/icons_monochrome/tracker/easy.svg',
            'themes/default/images_custom/icons_monochrome/tracker/hard.svg',
            'themes/default/images_custom/icons_monochrome/tracker/index.html',
            'themes/default/images_custom/icons_monochrome/tracker/minus.svg',
            'themes/default/images_custom/icons_monochrome/tracker/plus.svg',
            'themes/default/javascript_custom/cms_homesite_tracker.js',
            'themes/default/templates_custom/BLOCK_MAIN_MANTIS_TRACKER.tpl',
            'themes/default/templates_custom/MANTIS_TRACKER.tpl',
            'tracker/.editorconfig',
            'tracker/.imgbotconfig',
            'tracker/account_delete.php',
            'tracker/account_manage_columns_page.php',
            'tracker/account_page.php',
            'tracker/account_prefs_inc.php',
            'tracker/account_prefs_page.php',
            'tracker/account_prefs_reset.php',
            'tracker/account_prefs_update.php',
            'tracker/account_prof_edit_page.php',
            'tracker/account_prof_menu_page.php',
            'tracker/account_prof_update.php',
            'tracker/account_sponsor_page.php',
            'tracker/account_sponsor_update.php',
            'tracker/account_update.php',
            'tracker/adm_config_delete.php',
            'tracker/adm_config_page.php',
            'tracker/adm_config_report.php',
            'tracker/adm_config_set.php',
            'tracker/adm_permissions_report.php',
            'tracker/api/rest/.htaccess',
            'tracker/api/rest/index.php',
            'tracker/api/rest/restcore/.htaccess',
            'tracker/api/rest/restcore/ApiEnabledMiddleware.php',
            'tracker/api/rest/restcore/AuthMiddleware.php',
            'tracker/api/rest/restcore/CacheMiddleware.php',
            'tracker/api/rest/restcore/OfflineMiddleware.php',
            'tracker/api/rest/restcore/VersionMiddleware.php',
            'tracker/api/rest/restcore/config_rest.php',
            'tracker/api/rest/restcore/filters_rest.php',
            'tracker/api/rest/restcore/internal_rest.php',
            'tracker/api/rest/restcore/issues_rest.php',
            'tracker/api/rest/restcore/lang_rest.php',
            'tracker/api/rest/restcore/pages_rest.php',
            'tracker/api/rest/restcore/projects_rest.php',
            'tracker/api/rest/restcore/users_rest.php',
            'tracker/api/rest/swagger.json',
            'tracker/api/rest/web.config',
            'tracker/api/soap/mantisconnect.php',
            'tracker/api/soap/mantisconnect.wsdl',
            'tracker/api/soap/mc_account_api.php',
            'tracker/api/soap/mc_api.php',
            'tracker/api/soap/mc_config_api.php',
            'tracker/api/soap/mc_core.php',
            'tracker/api/soap/mc_custom_field_api.php',
            'tracker/api/soap/mc_enum_api.php',
            'tracker/api/soap/mc_file_api.php',
            'tracker/api/soap/mc_filter_api.php',
            'tracker/api/soap/mc_issue_api.php',
            'tracker/api/soap/mc_issue_attachment_api.php',
            'tracker/api/soap/mc_project_api.php',
            'tracker/api/soap/mc_project_attachment_api.php',
            'tracker/api/soap/mc_tag_api.php',
            'tracker/api/soap/mc_user_pref_api.php',
            'tracker/api/soap/mc_user_profile_api.php',
            'tracker/api/soap/wsdl-viewer.xsl',
            'tracker/api_token_create.php',
            'tracker/api_token_revoke.php',
            'tracker/api_tokens_page.php',
            'tracker/billing_export_to_csv.php',
            'tracker/billing_export_to_excel.php',
            'tracker/billing_inc.php',
            'tracker/billing_page.php',
            'tracker/browser_search_plugin.php',
            'tracker/bug_actiongroup.php',
            'tracker/bug_actiongroup_add_note_inc.php',
            'tracker/bug_actiongroup_attach_tags_inc.php',
            'tracker/bug_actiongroup_ext.php',
            'tracker/bug_actiongroup_ext_page.php',
            'tracker/bug_actiongroup_page.php',
            'tracker/bug_actiongroup_update_product_build_inc.php',
            'tracker/bug_actiongroup_update_severity_inc.php',
            'tracker/bug_change_status_page.php',
            'tracker/bug_file_delete.php',
            'tracker/bug_monitor_add.php',
            'tracker/bug_monitor_delete.php',
            'tracker/bug_monitor_list_view_inc.php',
            'tracker/bug_relationship_add.php',
            'tracker/bug_relationship_delete.php',
            'tracker/bug_relationship_graph.php',
            'tracker/bug_relationship_graph_img.php',
            'tracker/bug_reminder.php',
            'tracker/bug_reminder_page.php',
            'tracker/bug_report.php',
            'tracker/bug_report_page.php',
            'tracker/bug_revision_drop.php',
            'tracker/bug_revision_view_page.php',
            'tracker/bug_set_sponsorship.php',
            'tracker/bug_sponsorship_list_view_inc.php',
            'tracker/bug_stick.php',
            'tracker/bug_update.php',
            'tracker/bug_update_page.php',
            'tracker/bug_view_advanced_page.php',
            'tracker/bug_view_inc.php',
            'tracker/bug_view_page.php',
            'tracker/bugnote_add.php',
            'tracker/bugnote_add_inc.php',
            'tracker/bugnote_delete.php',
            'tracker/bugnote_edit_page.php',
            'tracker/bugnote_set_view_state.php',
            'tracker/bugnote_stats_inc.php',
            'tracker/bugnote_update.php',
            'tracker/bugnote_view_inc.php',
            'tracker/changelog_page.php',
            'tracker/composer.json',
            'tracker/composer.lock',
            'tracker/config/.htaccess',
            'tracker/config/Web.config',
            'tracker/config/config_inc.php',
            'tracker/config/config_inc.php.sample',
            'tracker/config_defaults_inc.php',
            'tracker/core.php',
            'tracker/core/.htaccess',
            'tracker/core/Web.config',
            'tracker/core/access_api.php',
            'tracker/core/antispam_api.php',
            'tracker/core/api_token_api.php',
            'tracker/core/authentication_api.php',
            'tracker/core/billing_api.php',
            'tracker/core/bug_activity_api.php',
            'tracker/core/bug_api.php',
            'tracker/core/bug_group_action_api.php',
            'tracker/core/bug_revision_api.php',
            'tracker/core/bugnote_api.php',
            'tracker/core/category_api.php',
            'tracker/core/cfdefs/cfdef_standard.php',
            'tracker/core/classes/AuthFlags.class.php',
            'tracker/core/classes/Avatar.class.php',
            'tracker/core/classes/BugFilterQuery.class.php',
            'tracker/core/classes/ConfigParser.class.php',
            'tracker/core/classes/DbQuery.class.php',
            'tracker/core/classes/FilterConverter.class.php',
            'tracker/core/classes/IssueAssignedTimelineEvent.class.php',
            'tracker/core/classes/IssueAttachmentTimelineEvent.class.php',
            'tracker/core/classes/IssueCreatedTimelineEvent.class.php',
            'tracker/core/classes/IssueMonitorTimelineEvent.class.php',
            'tracker/core/classes/IssueNoteCreatedTimelineEvent.class.php',
            'tracker/core/classes/IssueStatusChangeTimelineEvent.class.php',
            'tracker/core/classes/IssueTagTimelineEvent.class.php',
            'tracker/core/classes/MantisColumn.class.php',
            'tracker/core/classes/MantisCorePlugin.class.php',
            'tracker/core/classes/MantisCoreWikiPlugin.class.php',
            'tracker/core/classes/MantisEnum.class.php',
            'tracker/core/classes/MantisFilter.class.php',
            'tracker/core/classes/MantisFormattingPlugin.class.php',
            'tracker/core/classes/MantisPlugin.class.php',
            'tracker/core/classes/MantisWikiPlugin.class.php',
            'tracker/core/classes/TimelineEvent.class.php',
            'tracker/core/classes/Tokenizer.class.php',
            'tracker/core/collapse_api.php',
            'tracker/core/columns_api.php',
            'tracker/core/commands/Command.php',
            'tracker/core/commands/IssueAddCommand.php',
            'tracker/core/commands/IssueDeleteCommand.php',
            'tracker/core/commands/IssueFileAddCommand.php',
            'tracker/core/commands/IssueFileGetCommand.php',
            'tracker/core/commands/IssueNoteAddCommand.php',
            'tracker/core/commands/IssueNoteDeleteCommand.php',
            'tracker/core/commands/IssueRelationshipAddCommand.php',
            'tracker/core/commands/IssueRelationshipDeleteCommand.php',
            'tracker/core/commands/IssueViewPageCommand.php',
            'tracker/core/commands/MonitorAddCommand.php',
            'tracker/core/commands/ProjectHierarchyAddCommand.php',
            'tracker/core/commands/ProjectHierarchyDeleteCommand.php',
            'tracker/core/commands/ProjectHierarchyUpdateCommand.php',
            'tracker/core/commands/TagAttachCommand.php',
            'tracker/core/commands/TagDetachCommand.php',
            'tracker/core/commands/UserCreateCommand.php',
            'tracker/core/commands/UserDeleteCommand.php',
            'tracker/core/commands/UserResetPasswordCommand.php',
            'tracker/core/commands/VersionAddCommand.php',
            'tracker/core/compress_api.php',
            'tracker/core/config_api.php',
            'tracker/core/constant_inc.php',
            'tracker/core/crypto_api.php',
            'tracker/core/csv_api.php',
            'tracker/core/current_user_api.php',
            'tracker/core/custom_field_api.php',
            'tracker/core/custom_function_api.php',
            'tracker/core/database_api.php',
            'tracker/core/date_api.php',
            'tracker/core/email_api.php',
            'tracker/core/email_queue_api.php',
            'tracker/core/error_api.php',
            'tracker/core/event_api.php',
            'tracker/core/events_inc.php',
            'tracker/core/excel_api.php',
            'tracker/core/exceptions/ClientException.php',
            'tracker/core/exceptions/LegacyApiFaultException.php',
            'tracker/core/exceptions/MantisException.php',
            'tracker/core/exceptions/ServiceException.php',
            'tracker/core/exceptions/StateException.php',
            'tracker/core/file_api.php',
            'tracker/core/filter_api.php',
            'tracker/core/filter_constants_inc.php',
            'tracker/core/filter_form_api.php',
            'tracker/core/form_api.php',
            'tracker/core/gpc_api.php',
            'tracker/core/graphviz_api.php',
            'tracker/core/helper_api.php',
            'tracker/core/history_api.php',
            'tracker/core/html_api.php',
            'tracker/core/http_api.php',
            'tracker/core/icon_api.php',
            'tracker/core/install_helper_functions_api.php',
            'tracker/core/json_api.php',
            'tracker/core/lang_api.php',
            'tracker/core/last_visited_api.php',
            'tracker/core/layout_api.php',
            'tracker/core/ldap_api.php',
            'tracker/core/logging_api.php',
            'tracker/core/mention_api.php',
            'tracker/core/news_api.php',
            'tracker/core/obsolete.php',
            'tracker/core/php_api.php',
            'tracker/core/plugin_api.php',
            'tracker/core/prepare_api.php',
            'tracker/core/print_api.php',
            'tracker/core/profile_api.php',
            'tracker/core/project_api.php',
            'tracker/core/project_hierarchy_api.php',
            'tracker/core/relationship_api.php',
            'tracker/core/relationship_graph_api.php',
            'tracker/core/rss_api.php',
            'tracker/core/session_api.php',
            'tracker/core/sponsorship_api.php',
            'tracker/core/string_api.php',
            'tracker/core/summary_api.php',
            'tracker/core/tag_api.php',
            'tracker/core/timeline_api.php',
            'tracker/core/timeline_inc.php',
            'tracker/core/tokens_api.php',
            'tracker/core/url_api.php',
            'tracker/core/user_api.php',
            'tracker/core/user_pref_api.php',
            'tracker/core/utility_api.php',
            'tracker/core/version_api.php',
            'tracker/core/wiki_api.php',
            'tracker/core/workflow_api.php',
            'tracker/css/ace-mantis.css',
            'tracker/css/ace-part2.css',
            'tracker/css/ace-rtl.css',
            'tracker/css/ace-rtl.min.css',
            'tracker/css/ace-skins.css',
            'tracker/css/ace-skins.min.css',
            'tracker/css/ace.css',
            'tracker/css/ace.min.css',
            'tracker/css/bootstrap-3.4.1.css',
            'tracker/css/bootstrap-3.4.1.min.css',
            'tracker/css/bootstrap-datetimepicker-4.17.47.min.css',
            'tracker/css/default.css',
            'tracker/css/dropzone-5.5.0.css',
            'tracker/css/dropzone-5.5.0.min.css',
            'tracker/css/font-awesome-4.6.3.min.css',
            'tracker/css/fonts.css',
            'tracker/css/images/ajax-loader.gif',
            'tracker/css/images/ajax-loader.png',
            'tracker/css/images/icons-18-black.png',
            'tracker/css/images/icons-18-white.png',
            'tracker/css/images/icons-36-black.png',
            'tracker/css/images/icons-36-white.png',
            'tracker/css/images/pattern.jpg',
            'tracker/css/images/ui-bg_diagonals-thick_18_b81900_40x40.png',
            'tracker/css/images/ui-bg_diagonals-thick_20_666666_40x40.png',
            'tracker/css/images/ui-bg_flat_0_aaaaaa_40x100.png',
            'tracker/css/images/ui-bg_flat_10_000000_40x100.png',
            'tracker/css/images/ui-bg_flat_75_ffffff_40x100.png',
            'tracker/css/images/ui-bg_glass_100_f6f6f6_1x400.png',
            'tracker/css/images/ui-bg_glass_100_fdf5ce_1x400.png',
            'tracker/css/images/ui-bg_glass_55_fbf9ee_1x400.png',
            'tracker/css/images/ui-bg_glass_65_ffffff_1x400.png',
            'tracker/css/images/ui-bg_glass_75_dadada_1x400.png',
            'tracker/css/images/ui-bg_glass_75_e6e6e6_1x400.png',
            'tracker/css/images/ui-bg_glass_95_fef1ec_1x400.png',
            'tracker/css/images/ui-bg_gloss-wave_35_f6a828_500x100.png',
            'tracker/css/images/ui-bg_highlight-soft_100_eeeeee_1x100.png',
            'tracker/css/images/ui-bg_highlight-soft_75_cccccc_1x100.png',
            'tracker/css/images/ui-bg_highlight-soft_75_ffe45c_1x100.png',
            'tracker/css/images/ui-icons_222222_256x240.png',
            'tracker/css/images/ui-icons_228ef1_256x240.png',
            'tracker/css/images/ui-icons_2e83ff_256x240.png',
            'tracker/css/images/ui-icons_454545_256x240.png',
            'tracker/css/images/ui-icons_888888_256x240.png',
            'tracker/css/images/ui-icons_cd0a0a_256x240.png',
            'tracker/css/images/ui-icons_ef8c08_256x240.png',
            'tracker/css/images/ui-icons_ffd27a_256x240.png',
            'tracker/css/images/ui-icons_ffffff_256x240.png',
            'tracker/css/login.css',
            'tracker/css/rtl.css',
            'tracker/css/status_config.php',
            'tracker/csv_export.php',
            'tracker/excel_xml_export.php',
            'tracker/file_download.php',
            'tracker/fonts/.htaccess',
            'tracker/fonts/fontawesome-webfont.eot',
            'tracker/fonts/fontawesome-webfont.svg',
            'tracker/fonts/fontawesome-webfont.ttf',
            'tracker/fonts/fontawesome-webfont.woff',
            'tracker/fonts/fontawesome-webfont.woff2',
            'tracker/fonts/glyphicons-halflings-regular.eot',
            'tracker/fonts/glyphicons-halflings-regular.svg',
            'tracker/fonts/glyphicons-halflings-regular.ttf',
            'tracker/fonts/glyphicons-halflings-regular.woff',
            'tracker/fonts/glyphicons-halflings-regular.woff2',
            'tracker/fonts/montserrat-v12-cyrillic-ext-regular.woff',
            'tracker/fonts/montserrat-v12-cyrillic-ext-regular.woff2',
            'tracker/fonts/montserrat-v12-cyrillic-regular.woff',
            'tracker/fonts/montserrat-v12-cyrillic-regular.woff2',
            'tracker/fonts/montserrat-v12-latin-ext-regular.woff',
            'tracker/fonts/montserrat-v12-latin-ext-regular.woff2',
            'tracker/fonts/montserrat-v12-latin-regular.woff',
            'tracker/fonts/montserrat-v12-latin-regular.woff2',
            'tracker/fonts/montserrat-v12-vietnamese-regular.woff',
            'tracker/fonts/montserrat-v12-vietnamese-regular.woff2',
            'tracker/fonts/open-sans-v15-cyrillic-ext-regular.woff',
            'tracker/fonts/open-sans-v15-cyrillic-ext-regular.woff2',
            'tracker/fonts/open-sans-v15-cyrillic-regular.woff',
            'tracker/fonts/open-sans-v15-cyrillic-regular.woff2',
            'tracker/fonts/open-sans-v15-greek-ext-regular.woff',
            'tracker/fonts/open-sans-v15-greek-ext-regular.woff2',
            'tracker/fonts/open-sans-v15-greek-regular.woff',
            'tracker/fonts/open-sans-v15-greek-regular.woff2',
            'tracker/fonts/open-sans-v15-latin-ext-regular.woff',
            'tracker/fonts/open-sans-v15-latin-ext-regular.woff2',
            'tracker/fonts/open-sans-v15-latin-regular.woff',
            'tracker/fonts/open-sans-v15-latin-regular.woff2',
            'tracker/fonts/open-sans-v15-vietnamese-regular.woff',
            'tracker/fonts/open-sans-v15-vietnamese-regular.woff2',
            'tracker/fonts/poppins-v5-devanagari-regular.woff',
            'tracker/fonts/poppins-v5-devanagari-regular.woff2',
            'tracker/fonts/poppins-v5-latin-ext-regular.woff',
            'tracker/fonts/poppins-v5-latin-ext-regular.woff2',
            'tracker/fonts/poppins-v5-latin-regular.woff',
            'tracker/fonts/poppins-v5-latin-regular.woff2',
            'tracker/images/avatar.png',
            'tracker/images/favicon.ico',
            'tracker/images/mantis_logo.gif',
            'tracker/images/mantis_logo.png',
            'tracker/images/mantis_logo_notext.png',
            'tracker/images/rel_dependant.png',
            'tracker/images/rel_duplicate.png',
            'tracker/images/rel_related.png',
            'tracker/index.php',
            'tracker/issues_rss.php',
            'tracker/javascript_config.php',
            'tracker/javascript_translations.php',
            'tracker/js/ace.js',
            'tracker/js/ace.min.js',
            'tracker/js/adm_config_report.js',
            'tracker/js/bootstrap-3.4.1.js',
            'tracker/js/bootstrap-3.4.1.min.js',
            'tracker/js/bootstrap-datetimepicker-4.17.47.min.js',
            'tracker/js/bugFilter.js',
            'tracker/js/common.js',
            'tracker/js/dropzone-5.5.0.js',
            'tracker/js/dropzone-5.5.0.min.js',
            'tracker/js/install.js',
            'tracker/js/jquery-2.2.4.min.js',
            'tracker/js/list-1.5.0.js',
            'tracker/js/list-1.5.0.min.js',
            'tracker/js/login.js',
            'tracker/js/manage_custom_field_edit_page.js',
            'tracker/js/manage_proj_edit_page.js',
            'tracker/js/moment-with-locales-2.24.0.min.js',
            'tracker/js/typeahead.jquery-1.3.0.min.js',
            'tracker/jump_to_bug.php',
            'tracker/lang/.htaccess',
            'tracker/lang/README',
            'tracker/lang/Web.config',
            'tracker/lang/strings_afrikaans.txt',
            'tracker/lang/strings_amharic.txt',
            'tracker/lang/strings_arabic.txt',
            'tracker/lang/strings_arabicegyptianspoken.txt',
            'tracker/lang/strings_asturian.txt',
            'tracker/lang/strings_basque.txt',
            'tracker/lang/strings_belarusian_tarask.txt',
            'tracker/lang/strings_breton.txt',
            'tracker/lang/strings_bulgarian.txt',
            'tracker/lang/strings_catalan.txt',
            'tracker/lang/strings_chinese_simplified.txt',
            'tracker/lang/strings_chinese_traditional.txt',
            'tracker/lang/strings_croatian.txt',
            'tracker/lang/strings_czech.txt',
            'tracker/lang/strings_danish.txt',
            'tracker/lang/strings_dutch.txt',
            'tracker/lang/strings_english.txt',
            'tracker/lang/strings_eo.txt',
            'tracker/lang/strings_estonian.txt',
            'tracker/lang/strings_finnish.txt',
            'tracker/lang/strings_french.txt',
            'tracker/lang/strings_galician.txt',
            'tracker/lang/strings_georgian.txt',
            'tracker/lang/strings_german.txt',
            'tracker/lang/strings_greek.txt',
            'tracker/lang/strings_hebrew.txt',
            'tracker/lang/strings_hungarian.txt',
            'tracker/lang/strings_icelandic.txt',
            'tracker/lang/strings_interlingua.txt',
            'tracker/lang/strings_italian.txt',
            'tracker/lang/strings_japanese.txt',
            'tracker/lang/strings_korean.txt',
            'tracker/lang/strings_latvian.txt',
            'tracker/lang/strings_lithuanian.txt',
            'tracker/lang/strings_luxembourgish.txt',
            'tracker/lang/strings_macedonian.txt',
            'tracker/lang/strings_norwegian_bokmal.txt',
            'tracker/lang/strings_norwegian_nynorsk.txt',
            'tracker/lang/strings_occitan.txt',
            'tracker/lang/strings_persian.txt',
            'tracker/lang/strings_polish.txt',
            'tracker/lang/strings_portuguese_brazil.txt',
            'tracker/lang/strings_portuguese_standard.txt',
            'tracker/lang/strings_qqq.txt',
            'tracker/lang/strings_ripoarisch.txt',
            'tracker/lang/strings_romanian.txt',
            'tracker/lang/strings_russian.txt',
            'tracker/lang/strings_serbian.txt',
            'tracker/lang/strings_serbian_latin.txt',
            'tracker/lang/strings_sh.txt',
            'tracker/lang/strings_skr-arab.txt',
            'tracker/lang/strings_slovak.txt',
            'tracker/lang/strings_slovene.txt',
            'tracker/lang/strings_spanish.txt',
            'tracker/lang/strings_swedish.txt',
            'tracker/lang/strings_swissgerman.txt',
            'tracker/lang/strings_tagalog.txt',
            'tracker/lang/strings_turkish.txt',
            'tracker/lang/strings_ukrainian.txt',
            'tracker/lang/strings_urdu.txt',
            'tracker/lang/strings_vietnamese.txt',
            'tracker/lang/strings_volapuk.txt',
            'tracker/lang/strings_zazaki.txt',
            'tracker/library/.htaccess',
            'tracker/library/README.md',
            'tracker/library/Web.config',
            'tracker/library/rssbuilder/class.ObjectIterator.inc.php',
            'tracker/library/rssbuilder/class.ObjectList.inc.php',
            'tracker/library/rssbuilder/class.RSSBase.inc.php',
            'tracker/library/rssbuilder/class.RSSBuilder.inc.php',
            'tracker/library/rssbuilder/class.RSSItem.inc.php',
            'tracker/library/rssbuilder/class.RSSItemList.inc.php',
            'tracker/library/rssbuilder/class.RSS_V_091.inc.php',
            'tracker/library/rssbuilder/class.RSS_V_100.inc.php',
            'tracker/library/rssbuilder/class.RSS_V_200.inc.php',
            'tracker/library/rssbuilder/class.RSS_V_abstract.inc.php',
            'tracker/library/rssbuilder/doc/changelog_rssbuilder.htm',
            'tracker/library/rssbuilder/doc/doc.css',
            'tracker/library/rssbuilder/index.html',
            'tracker/library/rssbuilder/interface.RSS.inc.php',
            'tracker/library/rssbuilder/readme_mantis.txt',
            'tracker/library/rssbuilder/rss_sample_script.php',
            'tracker/login.php',
            'tracker/login_anon.php',
            'tracker/login_cookie_test.php',
            'tracker/login_page.php',
            'tracker/login_password_page.php',
            'tracker/login_select_proj_page.php',
            'tracker/logout_page.php',
            'tracker/lost_pwd.php',
            'tracker/lost_pwd_page.php',
            'tracker/main_page.php',
            'tracker/manage_columns_copy.php',
            'tracker/manage_columns_inc.php',
            'tracker/manage_config_columns_page.php',
            'tracker/manage_config_columns_reset.php',
            'tracker/manage_config_columns_set.php',
            'tracker/manage_config_email_page.php',
            'tracker/manage_config_email_set.php',
            'tracker/manage_config_revert.php',
            'tracker/manage_config_work_threshold_page.php',
            'tracker/manage_config_work_threshold_set.php',
            'tracker/manage_config_workflow_graph_page.php',
            'tracker/manage_config_workflow_page.php',
            'tracker/manage_config_workflow_set.php',
            'tracker/manage_custom_field_create.php',
            'tracker/manage_custom_field_delete.php',
            'tracker/manage_custom_field_edit_page.php',
            'tracker/manage_custom_field_page.php',
            'tracker/manage_custom_field_proj_add.php',
            'tracker/manage_custom_field_update.php',
            'tracker/manage_filter_delete.php',
            'tracker/manage_filter_edit_page.php',
            'tracker/manage_filter_edit_update.php',
            'tracker/manage_filter_page.php',
            'tracker/manage_overview_page.php',
            'tracker/manage_plugin_install.php',
            'tracker/manage_plugin_page.php',
            'tracker/manage_plugin_uninstall.php',
            'tracker/manage_plugin_update.php',
            'tracker/manage_plugin_upgrade.php',
            'tracker/manage_prof_menu_page.php',
            'tracker/manage_proj_cat_add.php',
            'tracker/manage_proj_cat_copy.php',
            'tracker/manage_proj_cat_delete.php',
            'tracker/manage_proj_cat_edit_page.php',
            'tracker/manage_proj_cat_update.php',
            'tracker/manage_proj_create.php',
            'tracker/manage_proj_create_page.php',
            'tracker/manage_proj_custom_field_add_existing.php',
            'tracker/manage_proj_custom_field_copy.php',
            'tracker/manage_proj_custom_field_remove.php',
            'tracker/manage_proj_custom_field_update.php',
            'tracker/manage_proj_delete.php',
            'tracker/manage_proj_edit_page.php',
            'tracker/manage_proj_page.php',
            'tracker/manage_proj_subproj_add.php',
            'tracker/manage_proj_subproj_delete.php',
            'tracker/manage_proj_update.php',
            'tracker/manage_proj_update_children.php',
            'tracker/manage_proj_user_add.php',
            'tracker/manage_proj_user_copy.php',
            'tracker/manage_proj_user_remove.php',
            'tracker/manage_proj_user_update.php',
            'tracker/manage_proj_ver_add.php',
            'tracker/manage_proj_ver_copy.php',
            'tracker/manage_proj_ver_delete.php',
            'tracker/manage_proj_ver_edit_page.php',
            'tracker/manage_proj_ver_update.php',
            'tracker/manage_tags_page.php',
            'tracker/manage_user_create.php',
            'tracker/manage_user_create_page.php',
            'tracker/manage_user_delete.php',
            'tracker/manage_user_edit_page.php',
            'tracker/manage_user_impersonate.php',
            'tracker/manage_user_page.php',
            'tracker/manage_user_proj_add.php',
            'tracker/manage_user_proj_delete.php',
            'tracker/manage_user_prune.php',
            'tracker/manage_user_reset.php',
            'tracker/manage_user_update.php',
            'tracker/mantis_offline.php.sample',
            'tracker/my_view_inc.php',
            'tracker/my_view_page.php',
            'tracker/news_add.php',
            'tracker/news_edit_page.php',
            'tracker/news_list_page.php',
            'tracker/news_menu_page.php',
            'tracker/news_rss.php',
            'tracker/news_update.php',
            'tracker/news_view_page.php',
            'tracker/permalink_page.php',
            'tracker/plugin.php',
            'tracker/plugin_file.php',
            'tracker/plugins/.htaccess',
            'tracker/plugins/Gravatar/Gravatar.php',
            'tracker/plugins/Gravatar/README.md',
            'tracker/plugins/Gravatar/lang/strings_arabic.txt',
            'tracker/plugins/Gravatar/lang/strings_asturian.txt',
            'tracker/plugins/Gravatar/lang/strings_belarusian_tarask.txt',
            'tracker/plugins/Gravatar/lang/strings_breton.txt',
            'tracker/plugins/Gravatar/lang/strings_bulgarian.txt',
            'tracker/plugins/Gravatar/lang/strings_chinese_simplified.txt',
            'tracker/plugins/Gravatar/lang/strings_chinese_traditional.txt',
            'tracker/plugins/Gravatar/lang/strings_czech.txt',
            'tracker/plugins/Gravatar/lang/strings_danish.txt',
            'tracker/plugins/Gravatar/lang/strings_dutch.txt',
            'tracker/plugins/Gravatar/lang/strings_en-gb.txt',
            'tracker/plugins/Gravatar/lang/strings_english.txt',
            'tracker/plugins/Gravatar/lang/strings_eo.txt',
            'tracker/plugins/Gravatar/lang/strings_french.txt',
            'tracker/plugins/Gravatar/lang/strings_galician.txt',
            'tracker/plugins/Gravatar/lang/strings_german.txt',
            'tracker/plugins/Gravatar/lang/strings_greek.txt',
            'tracker/plugins/Gravatar/lang/strings_hungarian.txt',
            'tracker/plugins/Gravatar/lang/strings_icelandic.txt',
            'tracker/plugins/Gravatar/lang/strings_italian.txt',
            'tracker/plugins/Gravatar/lang/strings_japanese.txt',
            'tracker/plugins/Gravatar/lang/strings_korean.txt',
            'tracker/plugins/Gravatar/lang/strings_macedonian.txt',
            'tracker/plugins/Gravatar/lang/strings_norwegian_bokmal.txt',
            'tracker/plugins/Gravatar/lang/strings_portuguese_brazil.txt',
            'tracker/plugins/Gravatar/lang/strings_portuguese_standard.txt',
            'tracker/plugins/Gravatar/lang/strings_qqq.txt',
            'tracker/plugins/Gravatar/lang/strings_russian.txt',
            'tracker/plugins/Gravatar/lang/strings_spanish.txt',
            'tracker/plugins/Gravatar/lang/strings_swedish.txt',
            'tracker/plugins/Gravatar/lang/strings_turkish.txt',
            'tracker/plugins/Gravatar/lang/strings_ukrainian.txt',
            'tracker/plugins/Gravatar/lang/strings_vietnamese.txt',
            'tracker/plugins/Gravatar/lang/strings_zazaki.txt',
            'tracker/plugins/MantisCoreFormatting/MantisCoreFormatting.php',
            'tracker/plugins/MantisCoreFormatting/core/MantisMarkdown.php',
            'tracker/plugins/MantisCoreFormatting/lang/strings_afrikaans.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_arabic.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_asturian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_basque.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_belarusian_tarask.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_bengali.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_bosnian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_breton.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_bulgarian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_catalan.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_chinese_simplified.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_chinese_traditional.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_czech.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_danish.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_dutch.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_english.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_eo.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_finnish.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_french.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_galician.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_georgian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_german.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_greek.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_hebrew.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_hungarian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_icelandic.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_indonesian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_interlingua.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_italian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_japanese.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_korean.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_laki.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_lezgi.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_lithuanian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_lower_sorbian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_luxembourgish.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_macedonian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_malay.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_malayalam.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_norwegian_bokmal.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_occitan.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_persian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_piedmontese.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_polish.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_portuguese_brazil.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_portuguese_standard.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_qqq.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_ripoarisch.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_romanian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_russian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_serbian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_serbian_latin.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_slovak.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_spanish.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_swedish.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_swissgerman.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_tachelhit.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_tagalog.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_telugu.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_turkish.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_ukrainian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_upper_sorbian.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_vietnamese.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_zazaki.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_zh-cn.txt',
            'tracker/plugins/MantisCoreFormatting/lang/strings_zh-hk.txt',
            'tracker/plugins/MantisCoreFormatting/pages/config.php',
            'tracker/plugins/MantisCoreFormatting/pages/config_edit.php',
            'tracker/plugins/MantisCoreFormatting/tests/MarkdownTest.php',
            'tracker/plugins/MantisGraph/MantisGraph.php',
            'tracker/plugins/MantisGraph/core/Period.php',
            'tracker/plugins/MantisGraph/core/graph_api.php',
            'tracker/plugins/MantisGraph/files/Chart-2.8.0.min.js',
            'tracker/plugins/MantisGraph/files/Chart.bundle-2.8.0.min.js',
            'tracker/plugins/MantisGraph/files/MantisGraph.js',
            'tracker/plugins/MantisGraph/files/chartjs-plugin-colorschemes-0.4.0.min.js',
            'tracker/plugins/MantisGraph/lang/strings_afrikaans.txt',
            'tracker/plugins/MantisGraph/lang/strings_arabic.txt',
            'tracker/plugins/MantisGraph/lang/strings_arabicegyptianspoken.txt',
            'tracker/plugins/MantisGraph/lang/strings_asturian.txt',
            'tracker/plugins/MantisGraph/lang/strings_basque.txt',
            'tracker/plugins/MantisGraph/lang/strings_belarusian_tarask.txt',
            'tracker/plugins/MantisGraph/lang/strings_breton.txt',
            'tracker/plugins/MantisGraph/lang/strings_bulgarian.txt',
            'tracker/plugins/MantisGraph/lang/strings_catalan.txt',
            'tracker/plugins/MantisGraph/lang/strings_chinese_simplified.txt',
            'tracker/plugins/MantisGraph/lang/strings_chinese_traditional.txt',
            'tracker/plugins/MantisGraph/lang/strings_czech.txt',
            'tracker/plugins/MantisGraph/lang/strings_danish.txt',
            'tracker/plugins/MantisGraph/lang/strings_dutch.txt',
            'tracker/plugins/MantisGraph/lang/strings_english.txt',
            'tracker/plugins/MantisGraph/lang/strings_eo.txt',
            'tracker/plugins/MantisGraph/lang/strings_estonian.txt',
            'tracker/plugins/MantisGraph/lang/strings_finnish.txt',
            'tracker/plugins/MantisGraph/lang/strings_french.txt',
            'tracker/plugins/MantisGraph/lang/strings_galician.txt',
            'tracker/plugins/MantisGraph/lang/strings_georgian.txt',
            'tracker/plugins/MantisGraph/lang/strings_german.txt',
            'tracker/plugins/MantisGraph/lang/strings_greek.txt',
            'tracker/plugins/MantisGraph/lang/strings_hebrew.txt',
            'tracker/plugins/MantisGraph/lang/strings_hungarian.txt',
            'tracker/plugins/MantisGraph/lang/strings_icelandic.txt',
            'tracker/plugins/MantisGraph/lang/strings_interlingua.txt',
            'tracker/plugins/MantisGraph/lang/strings_italian.txt',
            'tracker/plugins/MantisGraph/lang/strings_japanese.txt',
            'tracker/plugins/MantisGraph/lang/strings_korean.txt',
            'tracker/plugins/MantisGraph/lang/strings_laki.txt',
            'tracker/plugins/MantisGraph/lang/strings_lithuanian.txt',
            'tracker/plugins/MantisGraph/lang/strings_luxembourgish.txt',
            'tracker/plugins/MantisGraph/lang/strings_macedonian.txt',
            'tracker/plugins/MantisGraph/lang/strings_norwegian_bokmal.txt',
            'tracker/plugins/MantisGraph/lang/strings_norwegian_nynorsk.txt',
            'tracker/plugins/MantisGraph/lang/strings_occitan.txt',
            'tracker/plugins/MantisGraph/lang/strings_persian.txt',
            'tracker/plugins/MantisGraph/lang/strings_piedmontese.txt',
            'tracker/plugins/MantisGraph/lang/strings_polish.txt',
            'tracker/plugins/MantisGraph/lang/strings_portuguese_brazil.txt',
            'tracker/plugins/MantisGraph/lang/strings_portuguese_standard.txt',
            'tracker/plugins/MantisGraph/lang/strings_qqq.txt',
            'tracker/plugins/MantisGraph/lang/strings_ripoarisch.txt',
            'tracker/plugins/MantisGraph/lang/strings_romanian.txt',
            'tracker/plugins/MantisGraph/lang/strings_russian.txt',
            'tracker/plugins/MantisGraph/lang/strings_serbian.txt',
            'tracker/plugins/MantisGraph/lang/strings_serbian_latin.txt',
            'tracker/plugins/MantisGraph/lang/strings_slovak.txt',
            'tracker/plugins/MantisGraph/lang/strings_spanish.txt',
            'tracker/plugins/MantisGraph/lang/strings_swedish.txt',
            'tracker/plugins/MantisGraph/lang/strings_swissgerman.txt',
            'tracker/plugins/MantisGraph/lang/strings_tagalog.txt',
            'tracker/plugins/MantisGraph/lang/strings_turkish.txt',
            'tracker/plugins/MantisGraph/lang/strings_ukrainian.txt',
            'tracker/plugins/MantisGraph/lang/strings_urdu.txt',
            'tracker/plugins/MantisGraph/lang/strings_vietnamese.txt',
            'tracker/plugins/MantisGraph/lang/strings_volapuk.txt',
            'tracker/plugins/MantisGraph/lang/strings_zazaki.txt',
            'tracker/plugins/MantisGraph/lang/strings_zh-cn.txt',
            'tracker/plugins/MantisGraph/pages/category_graph.php',
            'tracker/plugins/MantisGraph/pages/developer_graph.php',
            'tracker/plugins/MantisGraph/pages/issues_trend_bycategory_table.php',
            'tracker/plugins/MantisGraph/pages/issues_trend_bystatus_table.php',
            'tracker/plugins/MantisGraph/pages/issues_trend_graph.php',
            'tracker/plugins/MantisGraph/pages/issues_trend_page.php',
            'tracker/plugins/MantisGraph/pages/priority_graph.php',
            'tracker/plugins/MantisGraph/pages/reporter_graph.php',
            'tracker/plugins/MantisGraph/pages/resolution_graph.php',
            'tracker/plugins/MantisGraph/pages/severity_graph.php',
            'tracker/plugins/MantisGraph/pages/status_graph.php',
            'tracker/plugins/Web.config',
            'tracker/plugins/XmlImportExport/ImportXml.php',
            'tracker/plugins/XmlImportExport/ImportXml/Interface.php',
            'tracker/plugins/XmlImportExport/ImportXml/Issue.php',
            'tracker/plugins/XmlImportExport/ImportXml/Mapper.php',
            'tracker/plugins/XmlImportExport/XmlImportExport.php',
            'tracker/plugins/XmlImportExport/lang/strings_afrikaans.txt',
            'tracker/plugins/XmlImportExport/lang/strings_arabic.txt',
            'tracker/plugins/XmlImportExport/lang/strings_arabicegyptianspoken.txt',
            'tracker/plugins/XmlImportExport/lang/strings_asturian.txt',
            'tracker/plugins/XmlImportExport/lang/strings_belarusian_tarask.txt',
            'tracker/plugins/XmlImportExport/lang/strings_bengali.txt',
            'tracker/plugins/XmlImportExport/lang/strings_breton.txt',
            'tracker/plugins/XmlImportExport/lang/strings_bulgarian.txt',
            'tracker/plugins/XmlImportExport/lang/strings_catalan.txt',
            'tracker/plugins/XmlImportExport/lang/strings_chinese_simplified.txt',
            'tracker/plugins/XmlImportExport/lang/strings_chinese_traditional.txt',
            'tracker/plugins/XmlImportExport/lang/strings_czech.txt',
            'tracker/plugins/XmlImportExport/lang/strings_danish.txt',
            'tracker/plugins/XmlImportExport/lang/strings_dutch.txt',
            'tracker/plugins/XmlImportExport/lang/strings_english.txt',
            'tracker/plugins/XmlImportExport/lang/strings_eo.txt',
            'tracker/plugins/XmlImportExport/lang/strings_finnish.txt',
            'tracker/plugins/XmlImportExport/lang/strings_french.txt',
            'tracker/plugins/XmlImportExport/lang/strings_galician.txt',
            'tracker/plugins/XmlImportExport/lang/strings_georgian.txt',
            'tracker/plugins/XmlImportExport/lang/strings_german.txt',
            'tracker/plugins/XmlImportExport/lang/strings_greek.txt',
            'tracker/plugins/XmlImportExport/lang/strings_hebrew.txt',
            'tracker/plugins/XmlImportExport/lang/strings_hungarian.txt',
            'tracker/plugins/XmlImportExport/lang/strings_icelandic.txt',
            'tracker/plugins/XmlImportExport/lang/strings_indonesian.txt',
            'tracker/plugins/XmlImportExport/lang/strings_interlingua.txt',
            'tracker/plugins/XmlImportExport/lang/strings_italian.txt',
            'tracker/plugins/XmlImportExport/lang/strings_japanese.txt',
            'tracker/plugins/XmlImportExport/lang/strings_korean.txt',
            'tracker/plugins/XmlImportExport/lang/strings_lithuanian.txt',
            'tracker/plugins/XmlImportExport/lang/strings_luxembourgish.txt',
            'tracker/plugins/XmlImportExport/lang/strings_macedonian.txt',
            'tracker/plugins/XmlImportExport/lang/strings_mirandese.txt',
            'tracker/plugins/XmlImportExport/lang/strings_norwegian_bokmal.txt',
            'tracker/plugins/XmlImportExport/lang/strings_occitan.txt',
            'tracker/plugins/XmlImportExport/lang/strings_piedmontese.txt',
            'tracker/plugins/XmlImportExport/lang/strings_polish.txt',
            'tracker/plugins/XmlImportExport/lang/strings_portuguese_brazil.txt',
            'tracker/plugins/XmlImportExport/lang/strings_portuguese_standard.txt',
            'tracker/plugins/XmlImportExport/lang/strings_qqq.txt',
            'tracker/plugins/XmlImportExport/lang/strings_ripoarisch.txt',
            'tracker/plugins/XmlImportExport/lang/strings_romanian.txt',
            'tracker/plugins/XmlImportExport/lang/strings_russian.txt',
            'tracker/plugins/XmlImportExport/lang/strings_serbian.txt',
            'tracker/plugins/XmlImportExport/lang/strings_serbian_latin.txt',
            'tracker/plugins/XmlImportExport/lang/strings_slovak.txt',
            'tracker/plugins/XmlImportExport/lang/strings_spanish.txt',
            'tracker/plugins/XmlImportExport/lang/strings_swedish.txt',
            'tracker/plugins/XmlImportExport/lang/strings_swissgerman.txt',
            'tracker/plugins/XmlImportExport/lang/strings_tagalog.txt',
            'tracker/plugins/XmlImportExport/lang/strings_tunisian_arabic.txt',
            'tracker/plugins/XmlImportExport/lang/strings_turkish.txt',
            'tracker/plugins/XmlImportExport/lang/strings_ukrainian.txt',
            'tracker/plugins/XmlImportExport/lang/strings_vietnamese.txt',
            'tracker/plugins/XmlImportExport/lang/strings_zazaki.txt',
            'tracker/plugins/XmlImportExport/lang/strings_zh-cn.txt',
            'tracker/plugins/XmlImportExport/lang/strings_zh-hk.txt',
            'tracker/plugins/XmlImportExport/mantis.dtd',
            'tracker/plugins/XmlImportExport/pages/config.php',
            'tracker/plugins/XmlImportExport/pages/config_page.php',
            'tracker/plugins/XmlImportExport/pages/export.php',
            'tracker/plugins/XmlImportExport/pages/import.php',
            'tracker/plugins/XmlImportExport/pages/import_action.php',
            'tracker/print_all_bug_options_inc.php',
            'tracker/print_all_bug_options_page.php',
            'tracker/print_all_bug_options_reset.php',
            'tracker/print_all_bug_options_update.php',
            'tracker/print_all_bug_page.php',
            'tracker/print_all_bug_page_word.php',
            'tracker/proj_doc_add.php',
            'tracker/proj_doc_add_page.php',
            'tracker/proj_doc_delete.php',
            'tracker/proj_doc_edit_page.php',
            'tracker/proj_doc_page.php',
            'tracker/proj_doc_update.php',
            'tracker/project_page.php',
            'tracker/query_store.php',
            'tracker/query_store_page.php',
            'tracker/readme.md',
            'tracker/return_dynamic_filters.php',
            'tracker/roadmap_page.php',
            'tracker/scripts/.htaccess',
            'tracker/scripts/README.md',
            'tracker/scripts/Web.config',
            'tracker/scripts/send_emails.php',
            'tracker/scripts/travis_before_script.sh',
            'tracker/scripts/travis_script.sh',
            'tracker/search.php',
            'tracker/set_project.php',
            'tracker/signup.php',
            'tracker/signup_page.php',
            'tracker/summary_page.php',
            'tracker/tag_attach.php',
            'tracker/tag_create.php',
            'tracker/tag_delete.php',
            'tracker/tag_detach.php',
            'tracker/tag_update.php',
            'tracker/tag_update_page.php',
            'tracker/tag_view_page.php',
            'tracker/uploads/index.html',
            'tracker/vendor/.htaccess',
            'tracker/vendor/Web.config',
            'tracker/vendor/adodb/adodb-php/.gitattributes',
            'tracker/vendor/adodb/adodb-php/.gitignore',
            'tracker/vendor/adodb/adodb-php/.mailmap',
            'tracker/vendor/adodb/adodb-php/LICENSE.md',
            'tracker/vendor/adodb/adodb-php/README.md',
            'tracker/vendor/adodb/adodb-php/adodb-active-record.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-active-recordx.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-csvlib.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-datadict.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-error.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-errorhandler.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-errorpear.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-exceptions.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-iterator.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-lib.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-memcache.lib.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-pager.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-pear.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-perf.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-php4.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-time.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-xmlschema.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb-xmlschema03.inc.php',
            'tracker/vendor/adodb/adodb-php/adodb.inc.php',
            'tracker/vendor/adodb/adodb-php/composer.json',
            'tracker/vendor/adodb/adodb-php/contrib/toxmlrpc.inc.php',
            'tracker/vendor/adodb/adodb-php/cute_icons_for_site/adodb.gif',
            'tracker/vendor/adodb/adodb-php/cute_icons_for_site/adodb2.gif',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-access.inc.php',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-db2.inc.php',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-firebird.inc.php',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-generic.inc.php',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-ibase.inc.php',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-informix.inc.php',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-mssql.inc.php',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-mssqlnative.inc.php',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-mysql.inc.php',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-oci8.inc.php',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-postgres.inc.php',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-sapdb.inc.php',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-sqlite.inc.php',
            'tracker/vendor/adodb/adodb-php/datadict/datadict-sybase.inc.php',
            'tracker/vendor/adodb/adodb-php/docs/README.md',
            'tracker/vendor/adodb/adodb-php/docs/adodb.gif',
            'tracker/vendor/adodb/adodb-php/docs/adodb2.gif',
            'tracker/vendor/adodb/adodb-php/docs/changelog.md',
            'tracker/vendor/adodb/adodb-php/docs/changelog_v2.x.md',
            'tracker/vendor/adodb/adodb-php/docs/changelog_v3.x.md',
            'tracker/vendor/adodb/adodb-php/docs/changelog_v4+5.md',
            'tracker/vendor/adodb/adodb-php/docs/changelog_v4.x.md',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-access.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-ado.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-ado5.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-ado_access.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-ado_mssql.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-ads.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-borland_ibase.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-csv.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-db2.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-db2oci.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-db2ora.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-fbsql.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-firebird.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-ibase.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-informix.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-informix72.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-ldap.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-mssql.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-mssql_n.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-mssqlnative.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-mssqlpo.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-mysql.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-mysqli.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-mysqlpo.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-mysqlt.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-netezza.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-oci8.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-oci805.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-oci8po.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-oci8quercus.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-odbc.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-odbc_db2.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-odbc_mssql.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-odbc_oracle.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-odbtp.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-odbtp_unicode.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-oracle.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-pdo.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-pdo_mssql.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-pdo_mysql.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-pdo_oci.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-pdo_pgsql.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-pdo_sqlite.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-pdo_sqlsrv.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-postgres.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-postgres64.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-postgres7.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-postgres8.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-postgres9.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-proxy.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-sapdb.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-sqlanywhere.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-sqlite.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-sqlite3.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-sqlitepo.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-sybase.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-sybase_ase.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-text.inc.php',
            'tracker/vendor/adodb/adodb-php/drivers/adodb-vfp.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-ar.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-bg.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-ca.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-cn.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-cz.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-da.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-de.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-en.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-eo.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-es.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-fa.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-fr.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-hu.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-it.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-nl.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-pl.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-pt-br.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-ro.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-ru.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-sv.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-th.inc.php',
            'tracker/vendor/adodb/adodb-php/lang/adodb-uk.inc.php',
            'tracker/vendor/adodb/adodb-php/pear/Auth/Container/ADOdb.php',
            'tracker/vendor/adodb/adodb-php/pear/auth_adodb_example.php',
            'tracker/vendor/adodb/adodb-php/pear/readme.Auth.txt',
            'tracker/vendor/adodb/adodb-php/perf/perf-db2.inc.php',
            'tracker/vendor/adodb/adodb-php/perf/perf-informix.inc.php',
            'tracker/vendor/adodb/adodb-php/perf/perf-mssql.inc.php',
            'tracker/vendor/adodb/adodb-php/perf/perf-mssqlnative.inc.php',
            'tracker/vendor/adodb/adodb-php/perf/perf-mysql.inc.php',
            'tracker/vendor/adodb/adodb-php/perf/perf-oci8.inc.php',
            'tracker/vendor/adodb/adodb-php/perf/perf-postgres.inc.php',
            'tracker/vendor/adodb/adodb-php/pivottable.inc.php',
            'tracker/vendor/adodb/adodb-php/replicate/adodb-replicate.inc.php',
            'tracker/vendor/adodb/adodb-php/replicate/replicate-steps.php',
            'tracker/vendor/adodb/adodb-php/replicate/test-tnb.php',
            'tracker/vendor/adodb/adodb-php/rsfilter.inc.php',
            'tracker/vendor/adodb/adodb-php/scripts/.gitignore',
            'tracker/vendor/adodb/adodb-php/scripts/TARADO5.BAT',
            'tracker/vendor/adodb/adodb-php/scripts/buildrelease.py',
            'tracker/vendor/adodb/adodb-php/scripts/updateversion.py',
            'tracker/vendor/adodb/adodb-php/scripts/uploadrelease.py',
            'tracker/vendor/adodb/adodb-php/server.php',
            'tracker/vendor/adodb/adodb-php/session/adodb-compress-bzip2.php',
            'tracker/vendor/adodb/adodb-php/session/adodb-compress-gzip.php',
            'tracker/vendor/adodb/adodb-php/session/adodb-cryptsession.php',
            'tracker/vendor/adodb/adodb-php/session/adodb-cryptsession2.php',
            'tracker/vendor/adodb/adodb-php/session/adodb-encrypt-mcrypt.php',
            'tracker/vendor/adodb/adodb-php/session/adodb-encrypt-md5.php',
            'tracker/vendor/adodb/adodb-php/session/adodb-encrypt-secret.php',
            'tracker/vendor/adodb/adodb-php/session/adodb-encrypt-sha1.php',
            'tracker/vendor/adodb/adodb-php/session/adodb-sess.txt',
            'tracker/vendor/adodb/adodb-php/session/adodb-session-clob.php',
            'tracker/vendor/adodb/adodb-php/session/adodb-session-clob2.php',
            'tracker/vendor/adodb/adodb-php/session/adodb-session.php',
            'tracker/vendor/adodb/adodb-php/session/adodb-session2.php',
            'tracker/vendor/adodb/adodb-php/session/adodb-sessions.mysql.sql',
            'tracker/vendor/adodb/adodb-php/session/adodb-sessions.oracle.clob.sql',
            'tracker/vendor/adodb/adodb-php/session/adodb-sessions.oracle.sql',
            'tracker/vendor/adodb/adodb-php/session/crypt.inc.php',
            'tracker/vendor/adodb/adodb-php/session/old/adodb-cryptsession.php',
            'tracker/vendor/adodb/adodb-php/session/old/adodb-session-clob.php',
            'tracker/vendor/adodb/adodb-php/session/old/adodb-session.php',
            'tracker/vendor/adodb/adodb-php/session/old/crypt.inc.php',
            'tracker/vendor/adodb/adodb-php/session/session_schema.xml',
            'tracker/vendor/adodb/adodb-php/session/session_schema2.xml',
            'tracker/vendor/adodb/adodb-php/tests/benchmark.php',
            'tracker/vendor/adodb/adodb-php/tests/client.php',
            'tracker/vendor/adodb/adodb-php/tests/pdo.php',
            'tracker/vendor/adodb/adodb-php/tests/test-active-record.php',
            'tracker/vendor/adodb/adodb-php/tests/test-active-recs2.php',
            'tracker/vendor/adodb/adodb-php/tests/test-active-relations.php',
            'tracker/vendor/adodb/adodb-php/tests/test-active-relationsx.php',
            'tracker/vendor/adodb/adodb-php/tests/test-datadict.php',
            'tracker/vendor/adodb/adodb-php/tests/test-perf.php',
            'tracker/vendor/adodb/adodb-php/tests/test-pgblob.php',
            'tracker/vendor/adodb/adodb-php/tests/test-php5.php',
            'tracker/vendor/adodb/adodb-php/tests/test-xmlschema.php',
            'tracker/vendor/adodb/adodb-php/tests/test.php',
            'tracker/vendor/adodb/adodb-php/tests/test2.php',
            'tracker/vendor/adodb/adodb-php/tests/test3.php',
            'tracker/vendor/adodb/adodb-php/tests/test4.php',
            'tracker/vendor/adodb/adodb-php/tests/test5.php',
            'tracker/vendor/adodb/adodb-php/tests/test_rs_array.php',
            'tracker/vendor/adodb/adodb-php/tests/testcache.php',
            'tracker/vendor/adodb/adodb-php/tests/testdatabases.inc.php',
            'tracker/vendor/adodb/adodb-php/tests/testgenid.php',
            'tracker/vendor/adodb/adodb-php/tests/testmssql.php',
            'tracker/vendor/adodb/adodb-php/tests/testoci8.php',
            'tracker/vendor/adodb/adodb-php/tests/testoci8cursor.php',
            'tracker/vendor/adodb/adodb-php/tests/testpaging.php',
            'tracker/vendor/adodb/adodb-php/tests/testpear.php',
            'tracker/vendor/adodb/adodb-php/tests/testsessions.php',
            'tracker/vendor/adodb/adodb-php/tests/time.php',
            'tracker/vendor/adodb/adodb-php/tests/tmssql.php',
            'tracker/vendor/adodb/adodb-php/tests/xmlschema-mssql.xml',
            'tracker/vendor/adodb/adodb-php/tests/xmlschema.xml',
            'tracker/vendor/adodb/adodb-php/toexport.inc.php',
            'tracker/vendor/adodb/adodb-php/tohtml.inc.php',
            'tracker/vendor/adodb/adodb-php/xmlschema.dtd',
            'tracker/vendor/adodb/adodb-php/xmlschema03.dtd',
            'tracker/vendor/adodb/adodb-php/xsl/convert-0.1-0.2.xsl',
            'tracker/vendor/adodb/adodb-php/xsl/convert-0.1-0.3.xsl',
            'tracker/vendor/adodb/adodb-php/xsl/convert-0.2-0.1.xsl',
            'tracker/vendor/adodb/adodb-php/xsl/convert-0.2-0.3.xsl',
            'tracker/vendor/adodb/adodb-php/xsl/remove-0.2.xsl',
            'tracker/vendor/adodb/adodb-php/xsl/remove-0.3.xsl',
            'tracker/vendor/autoload.php',
            'tracker/vendor/composer/ClassLoader.php',
            'tracker/vendor/composer/LICENSE',
            'tracker/vendor/composer/autoload_classmap.php',
            'tracker/vendor/composer/autoload_files.php',
            'tracker/vendor/composer/autoload_namespaces.php',
            'tracker/vendor/composer/autoload_psr4.php',
            'tracker/vendor/composer/autoload_real.php',
            'tracker/vendor/composer/autoload_static.php',
            'tracker/vendor/composer/installed.json',
            'tracker/vendor/dapphp/securimage/.gitattributes',
            'tracker/vendor/dapphp/securimage/.htaccess',
            'tracker/vendor/dapphp/securimage/AHGBold.ttf',
            'tracker/vendor/dapphp/securimage/LICENSE.txt',
            'tracker/vendor/dapphp/securimage/README.FONT.txt',
            'tracker/vendor/dapphp/securimage/README.md',
            'tracker/vendor/dapphp/securimage/README.txt',
            'tracker/vendor/dapphp/securimage/WavFile.php',
            'tracker/vendor/dapphp/securimage/audio/.htaccess',
            'tracker/vendor/dapphp/securimage/audio/en/0.wav',
            'tracker/vendor/dapphp/securimage/audio/en/1.wav',
            'tracker/vendor/dapphp/securimage/audio/en/10.wav',
            'tracker/vendor/dapphp/securimage/audio/en/11.wav',
            'tracker/vendor/dapphp/securimage/audio/en/12.wav',
            'tracker/vendor/dapphp/securimage/audio/en/13.wav',
            'tracker/vendor/dapphp/securimage/audio/en/14.wav',
            'tracker/vendor/dapphp/securimage/audio/en/15.wav',
            'tracker/vendor/dapphp/securimage/audio/en/16.wav',
            'tracker/vendor/dapphp/securimage/audio/en/17.wav',
            'tracker/vendor/dapphp/securimage/audio/en/18.wav',
            'tracker/vendor/dapphp/securimage/audio/en/19.wav',
            'tracker/vendor/dapphp/securimage/audio/en/2.wav',
            'tracker/vendor/dapphp/securimage/audio/en/20.wav',
            'tracker/vendor/dapphp/securimage/audio/en/3.wav',
            'tracker/vendor/dapphp/securimage/audio/en/4.wav',
            'tracker/vendor/dapphp/securimage/audio/en/5.wav',
            'tracker/vendor/dapphp/securimage/audio/en/6.wav',
            'tracker/vendor/dapphp/securimage/audio/en/7.wav',
            'tracker/vendor/dapphp/securimage/audio/en/8.wav',
            'tracker/vendor/dapphp/securimage/audio/en/9.wav',
            'tracker/vendor/dapphp/securimage/audio/en/A.wav',
            'tracker/vendor/dapphp/securimage/audio/en/B.wav',
            'tracker/vendor/dapphp/securimage/audio/en/C.wav',
            'tracker/vendor/dapphp/securimage/audio/en/D.wav',
            'tracker/vendor/dapphp/securimage/audio/en/E.wav',
            'tracker/vendor/dapphp/securimage/audio/en/F.wav',
            'tracker/vendor/dapphp/securimage/audio/en/G.wav',
            'tracker/vendor/dapphp/securimage/audio/en/H.wav',
            'tracker/vendor/dapphp/securimage/audio/en/I.wav',
            'tracker/vendor/dapphp/securimage/audio/en/J.wav',
            'tracker/vendor/dapphp/securimage/audio/en/K.wav',
            'tracker/vendor/dapphp/securimage/audio/en/L.wav',
            'tracker/vendor/dapphp/securimage/audio/en/M.wav',
            'tracker/vendor/dapphp/securimage/audio/en/MINUS.wav',
            'tracker/vendor/dapphp/securimage/audio/en/N.wav',
            'tracker/vendor/dapphp/securimage/audio/en/O.wav',
            'tracker/vendor/dapphp/securimage/audio/en/P.wav',
            'tracker/vendor/dapphp/securimage/audio/en/PLUS.wav',
            'tracker/vendor/dapphp/securimage/audio/en/Q.wav',
            'tracker/vendor/dapphp/securimage/audio/en/R.wav',
            'tracker/vendor/dapphp/securimage/audio/en/S.wav',
            'tracker/vendor/dapphp/securimage/audio/en/T.wav',
            'tracker/vendor/dapphp/securimage/audio/en/TIMES.wav',
            'tracker/vendor/dapphp/securimage/audio/en/U.wav',
            'tracker/vendor/dapphp/securimage/audio/en/V.wav',
            'tracker/vendor/dapphp/securimage/audio/en/W.wav',
            'tracker/vendor/dapphp/securimage/audio/en/X.wav',
            'tracker/vendor/dapphp/securimage/audio/en/Y.wav',
            'tracker/vendor/dapphp/securimage/audio/en/Z.wav',
            'tracker/vendor/dapphp/securimage/audio/en/error.wav',
            'tracker/vendor/dapphp/securimage/audio/noise/check-point-1.wav',
            'tracker/vendor/dapphp/securimage/audio/noise/crowd-talking-1.wav',
            'tracker/vendor/dapphp/securimage/audio/noise/crowd-talking-6.wav',
            'tracker/vendor/dapphp/securimage/audio/noise/crowd-talking-7.wav',
            'tracker/vendor/dapphp/securimage/audio/noise/kids-playing-1.wav',
            'tracker/vendor/dapphp/securimage/backgrounds/bg3.jpg',
            'tracker/vendor/dapphp/securimage/backgrounds/bg4.jpg',
            'tracker/vendor/dapphp/securimage/backgrounds/bg5.jpg',
            'tracker/vendor/dapphp/securimage/backgrounds/bg6.png',
            'tracker/vendor/dapphp/securimage/composer.json',
            'tracker/vendor/dapphp/securimage/database/.htaccess',
            'tracker/vendor/dapphp/securimage/database/index.html',
            'tracker/vendor/dapphp/securimage/database/securimage.sq3',
            'tracker/vendor/dapphp/securimage/images/audio_icon.png',
            'tracker/vendor/dapphp/securimage/images/loading.png',
            'tracker/vendor/dapphp/securimage/images/refresh.png',
            'tracker/vendor/dapphp/securimage/securimage.css',
            'tracker/vendor/dapphp/securimage/securimage.js',
            'tracker/vendor/dapphp/securimage/securimage.php',
            'tracker/vendor/dapphp/securimage/securimage_play.php',
            'tracker/vendor/dapphp/securimage/securimage_play.swf',
            'tracker/vendor/dapphp/securimage/securimage_show.php',
            'tracker/vendor/dapphp/securimage/web.config',
            'tracker/vendor/dapphp/securimage/words/words.txt',
            'tracker/vendor/doctrine/instantiator/.gitignore',
            'tracker/vendor/doctrine/instantiator/.scrutinizer.yml',
            'tracker/vendor/doctrine/instantiator/.travis.install.sh',
            'tracker/vendor/doctrine/instantiator/.travis.yml',
            'tracker/vendor/doctrine/instantiator/CONTRIBUTING.md',
            'tracker/vendor/doctrine/instantiator/LICENSE',
            'tracker/vendor/doctrine/instantiator/README.md',
            'tracker/vendor/doctrine/instantiator/composer.json',
            'tracker/vendor/doctrine/instantiator/phpmd.xml.dist',
            'tracker/vendor/doctrine/instantiator/phpunit.xml.dist',
            'tracker/vendor/doctrine/instantiator/src/Doctrine/Instantiator/Exception/ExceptionInterface.php',
            'tracker/vendor/doctrine/instantiator/src/Doctrine/Instantiator/Exception/InvalidArgumentException.php',
            'tracker/vendor/doctrine/instantiator/src/Doctrine/Instantiator/Exception/UnexpectedValueException.php',
            'tracker/vendor/doctrine/instantiator/src/Doctrine/Instantiator/Instantiator.php',
            'tracker/vendor/doctrine/instantiator/src/Doctrine/Instantiator/InstantiatorInterface.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorPerformance/InstantiatorPerformanceEvent.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTest/Exception/InvalidArgumentExceptionTest.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTest/Exception/UnexpectedValueExceptionTest.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTest/InstantiatorTest.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTestAsset/AbstractClassAsset.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTestAsset/ArrayObjectAsset.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTestAsset/ExceptionAsset.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTestAsset/FinalExceptionAsset.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTestAsset/PharAsset.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTestAsset/PharExceptionAsset.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTestAsset/SerializableArrayObjectAsset.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTestAsset/SimpleSerializableAsset.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTestAsset/SimpleTraitAsset.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTestAsset/UnCloneableAsset.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTestAsset/UnserializeExceptionArrayObjectAsset.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTestAsset/WakeUpNoticesAsset.php',
            'tracker/vendor/doctrine/instantiator/tests/DoctrineTest/InstantiatorTestAsset/XMLReaderAsset.php',
            'tracker/vendor/erusev/parsedown/LICENSE.txt',
            'tracker/vendor/erusev/parsedown/Parsedown.php',
            'tracker/vendor/erusev/parsedown/README.md',
            'tracker/vendor/erusev/parsedown/composer.json',
            'tracker/vendor/guzzlehttp/guzzle/.php_cs',
            'tracker/vendor/guzzlehttp/guzzle/CHANGELOG.md',
            'tracker/vendor/guzzlehttp/guzzle/Dockerfile',
            'tracker/vendor/guzzlehttp/guzzle/LICENSE',
            'tracker/vendor/guzzlehttp/guzzle/README.md',
            'tracker/vendor/guzzlehttp/guzzle/UPGRADING.md',
            'tracker/vendor/guzzlehttp/guzzle/composer.json',
            'tracker/vendor/guzzlehttp/guzzle/src/Client.php',
            'tracker/vendor/guzzlehttp/guzzle/src/ClientInterface.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Cookie/CookieJar.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Cookie/CookieJarInterface.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Cookie/FileCookieJar.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Cookie/SessionCookieJar.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Cookie/SetCookie.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Exception/BadResponseException.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Exception/ClientException.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Exception/ConnectException.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Exception/GuzzleException.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Exception/InvalidArgumentException.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Exception/RequestException.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Exception/SeekException.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Exception/ServerException.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Exception/TooManyRedirectsException.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Exception/TransferException.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Handler/CurlFactory.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Handler/CurlFactoryInterface.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Handler/CurlHandler.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Handler/CurlMultiHandler.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Handler/EasyHandle.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Handler/MockHandler.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Handler/Proxy.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Handler/StreamHandler.php',
            'tracker/vendor/guzzlehttp/guzzle/src/HandlerStack.php',
            'tracker/vendor/guzzlehttp/guzzle/src/MessageFormatter.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Middleware.php',
            'tracker/vendor/guzzlehttp/guzzle/src/Pool.php',
            'tracker/vendor/guzzlehttp/guzzle/src/PrepareBodyMiddleware.php',
            'tracker/vendor/guzzlehttp/guzzle/src/RedirectMiddleware.php',
            'tracker/vendor/guzzlehttp/guzzle/src/RequestOptions.php',
            'tracker/vendor/guzzlehttp/guzzle/src/RetryMiddleware.php',
            'tracker/vendor/guzzlehttp/guzzle/src/TransferStats.php',
            'tracker/vendor/guzzlehttp/guzzle/src/UriTemplate.php',
            'tracker/vendor/guzzlehttp/guzzle/src/functions.php',
            'tracker/vendor/guzzlehttp/guzzle/src/functions_include.php',
            'tracker/vendor/guzzlehttp/promises/CHANGELOG.md',
            'tracker/vendor/guzzlehttp/promises/LICENSE',
            'tracker/vendor/guzzlehttp/promises/Makefile',
            'tracker/vendor/guzzlehttp/promises/README.md',
            'tracker/vendor/guzzlehttp/promises/composer.json',
            'tracker/vendor/guzzlehttp/promises/src/AggregateException.php',
            'tracker/vendor/guzzlehttp/promises/src/CancellationException.php',
            'tracker/vendor/guzzlehttp/promises/src/Coroutine.php',
            'tracker/vendor/guzzlehttp/promises/src/EachPromise.php',
            'tracker/vendor/guzzlehttp/promises/src/FulfilledPromise.php',
            'tracker/vendor/guzzlehttp/promises/src/Promise.php',
            'tracker/vendor/guzzlehttp/promises/src/PromiseInterface.php',
            'tracker/vendor/guzzlehttp/promises/src/PromisorInterface.php',
            'tracker/vendor/guzzlehttp/promises/src/RejectedPromise.php',
            'tracker/vendor/guzzlehttp/promises/src/RejectionException.php',
            'tracker/vendor/guzzlehttp/promises/src/TaskQueue.php',
            'tracker/vendor/guzzlehttp/promises/src/TaskQueueInterface.php',
            'tracker/vendor/guzzlehttp/promises/src/functions.php',
            'tracker/vendor/guzzlehttp/promises/src/functions_include.php',
            'tracker/vendor/guzzlehttp/psr7/CHANGELOG.md',
            'tracker/vendor/guzzlehttp/psr7/LICENSE',
            'tracker/vendor/guzzlehttp/psr7/README.md',
            'tracker/vendor/guzzlehttp/psr7/composer.json',
            'tracker/vendor/guzzlehttp/psr7/src/AppendStream.php',
            'tracker/vendor/guzzlehttp/psr7/src/BufferStream.php',
            'tracker/vendor/guzzlehttp/psr7/src/CachingStream.php',
            'tracker/vendor/guzzlehttp/psr7/src/DroppingStream.php',
            'tracker/vendor/guzzlehttp/psr7/src/FnStream.php',
            'tracker/vendor/guzzlehttp/psr7/src/InflateStream.php',
            'tracker/vendor/guzzlehttp/psr7/src/LazyOpenStream.php',
            'tracker/vendor/guzzlehttp/psr7/src/LimitStream.php',
            'tracker/vendor/guzzlehttp/psr7/src/MessageTrait.php',
            'tracker/vendor/guzzlehttp/psr7/src/MultipartStream.php',
            'tracker/vendor/guzzlehttp/psr7/src/NoSeekStream.php',
            'tracker/vendor/guzzlehttp/psr7/src/PumpStream.php',
            'tracker/vendor/guzzlehttp/psr7/src/Request.php',
            'tracker/vendor/guzzlehttp/psr7/src/Response.php',
            'tracker/vendor/guzzlehttp/psr7/src/Rfc7230.php',
            'tracker/vendor/guzzlehttp/psr7/src/ServerRequest.php',
            'tracker/vendor/guzzlehttp/psr7/src/Stream.php',
            'tracker/vendor/guzzlehttp/psr7/src/StreamDecoratorTrait.php',
            'tracker/vendor/guzzlehttp/psr7/src/StreamWrapper.php',
            'tracker/vendor/guzzlehttp/psr7/src/UploadedFile.php',
            'tracker/vendor/guzzlehttp/psr7/src/Uri.php',
            'tracker/vendor/guzzlehttp/psr7/src/UriNormalizer.php',
            'tracker/vendor/guzzlehttp/psr7/src/UriResolver.php',
            'tracker/vendor/guzzlehttp/psr7/src/functions.php',
            'tracker/vendor/guzzlehttp/psr7/src/functions_include.php',
            'tracker/vendor/nikic/fast-route/.gitignore',
            'tracker/vendor/nikic/fast-route/.hhconfig',
            'tracker/vendor/nikic/fast-route/.travis.yml',
            'tracker/vendor/nikic/fast-route/FastRoute.hhi',
            'tracker/vendor/nikic/fast-route/LICENSE',
            'tracker/vendor/nikic/fast-route/README.md',
            'tracker/vendor/nikic/fast-route/composer.json',
            'tracker/vendor/nikic/fast-route/phpunit.xml',
            'tracker/vendor/nikic/fast-route/psalm.xml',
            'tracker/vendor/nikic/fast-route/src/BadRouteException.php',
            'tracker/vendor/nikic/fast-route/src/DataGenerator.php',
            'tracker/vendor/nikic/fast-route/src/DataGenerator/CharCountBased.php',
            'tracker/vendor/nikic/fast-route/src/DataGenerator/GroupCountBased.php',
            'tracker/vendor/nikic/fast-route/src/DataGenerator/GroupPosBased.php',
            'tracker/vendor/nikic/fast-route/src/DataGenerator/MarkBased.php',
            'tracker/vendor/nikic/fast-route/src/DataGenerator/RegexBasedAbstract.php',
            'tracker/vendor/nikic/fast-route/src/Dispatcher.php',
            'tracker/vendor/nikic/fast-route/src/Dispatcher/CharCountBased.php',
            'tracker/vendor/nikic/fast-route/src/Dispatcher/GroupCountBased.php',
            'tracker/vendor/nikic/fast-route/src/Dispatcher/GroupPosBased.php',
            'tracker/vendor/nikic/fast-route/src/Dispatcher/MarkBased.php',
            'tracker/vendor/nikic/fast-route/src/Dispatcher/RegexBasedAbstract.php',
            'tracker/vendor/nikic/fast-route/src/Route.php',
            'tracker/vendor/nikic/fast-route/src/RouteCollector.php',
            'tracker/vendor/nikic/fast-route/src/RouteParser.php',
            'tracker/vendor/nikic/fast-route/src/RouteParser/Std.php',
            'tracker/vendor/nikic/fast-route/src/bootstrap.php',
            'tracker/vendor/nikic/fast-route/src/functions.php',
            'tracker/vendor/nikic/fast-route/test/Dispatcher/CharCountBasedTest.php',
            'tracker/vendor/nikic/fast-route/test/Dispatcher/DispatcherTest.php',
            'tracker/vendor/nikic/fast-route/test/Dispatcher/GroupCountBasedTest.php',
            'tracker/vendor/nikic/fast-route/test/Dispatcher/GroupPosBasedTest.php',
            'tracker/vendor/nikic/fast-route/test/Dispatcher/MarkBasedTest.php',
            'tracker/vendor/nikic/fast-route/test/HackTypechecker/HackTypecheckerTest.php',
            'tracker/vendor/nikic/fast-route/test/HackTypechecker/fixtures/all_options.php',
            'tracker/vendor/nikic/fast-route/test/HackTypechecker/fixtures/empty_options.php',
            'tracker/vendor/nikic/fast-route/test/HackTypechecker/fixtures/no_options.php',
            'tracker/vendor/nikic/fast-route/test/RouteCollectorTest.php',
            'tracker/vendor/nikic/fast-route/test/RouteParser/StdTest.php',
            'tracker/vendor/nikic/fast-route/test/bootstrap.php',
            'tracker/vendor/phpdocumentor/reflection-common/.travis.yml',
            'tracker/vendor/phpdocumentor/reflection-common/LICENSE',
            'tracker/vendor/phpdocumentor/reflection-common/README.md',
            'tracker/vendor/phpdocumentor/reflection-common/composer.json',
            'tracker/vendor/phpdocumentor/reflection-common/src/Element.php',
            'tracker/vendor/phpdocumentor/reflection-common/src/File.php',
            'tracker/vendor/phpdocumentor/reflection-common/src/Fqsen.php',
            'tracker/vendor/phpdocumentor/reflection-common/src/Location.php',
            'tracker/vendor/phpdocumentor/reflection-common/src/Project.php',
            'tracker/vendor/phpdocumentor/reflection-common/src/ProjectFactory.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/LICENSE',
            'tracker/vendor/phpdocumentor/reflection-docblock/README.md',
            'tracker/vendor/phpdocumentor/reflection-docblock/composer.json',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Description.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/DescriptionFactory.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/ExampleFinder.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Serializer.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/StandardTagFactory.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tag.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/TagFactory.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Author.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/BaseTag.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Covers.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Deprecated.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Example.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Factory/StaticMethod.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Factory/Strategy.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Formatter.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Formatter/AlignFormatter.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Formatter/PassthroughFormatter.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Generic.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Link.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Method.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Param.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Property.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/PropertyRead.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/PropertyWrite.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Return_.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/See.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Since.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Source.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Throws.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Uses.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Var_.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlock/Tags/Version.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlockFactory.php',
            'tracker/vendor/phpdocumentor/reflection-docblock/src/DocBlockFactoryInterface.php',
            'tracker/vendor/phpdocumentor/type-resolver/LICENSE',
            'tracker/vendor/phpdocumentor/type-resolver/README.md',
            'tracker/vendor/phpdocumentor/type-resolver/composer.json',
            'tracker/vendor/phpdocumentor/type-resolver/src/FqsenResolver.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Type.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/TypeResolver.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Array_.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Boolean.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Callable_.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Compound.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Context.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/ContextFactory.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Float_.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Integer.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Iterable_.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Mixed.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Null_.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Nullable.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Object_.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Parent_.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Resource.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Scalar.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Self_.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Static_.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/String_.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/This.php',
            'tracker/vendor/phpdocumentor/type-resolver/src/Types/Void_.php',
            'tracker/vendor/phpmailer/phpmailer/COMMITMENT',
            'tracker/vendor/phpmailer/phpmailer/LICENSE',
            'tracker/vendor/phpmailer/phpmailer/README.md',
            'tracker/vendor/phpmailer/phpmailer/SECURITY.md',
            'tracker/vendor/phpmailer/phpmailer/VERSION',
            'tracker/vendor/phpmailer/phpmailer/composer.json',
            'tracker/vendor/phpmailer/phpmailer/get_oauth_token.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-af.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-am.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-ar.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-az.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-ba.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-be.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-bg.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-ca.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-ch.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-cs.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-da.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-de.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-el.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-eo.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-es.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-et.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-fa.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-fi.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-fo.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-fr.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-gl.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-he.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-hi.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-hr.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-hu.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-id.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-it.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-ja.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-ka.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-ko.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-lt.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-lv.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-mg.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-ms.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-nb.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-nl.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-pl.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-pt.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-pt_br.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-ro.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-ru.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-sk.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-sl.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-sr.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-sv.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-tl.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-tr.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-uk.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-vi.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-zh.php',
            'tracker/vendor/phpmailer/phpmailer/language/phpmailer.lang-zh_cn.php',
            'tracker/vendor/phpmailer/phpmailer/src/Exception.php',
            'tracker/vendor/phpmailer/phpmailer/src/OAuth.php',
            'tracker/vendor/phpmailer/phpmailer/src/PHPMailer.php',
            'tracker/vendor/phpmailer/phpmailer/src/POP3.php',
            'tracker/vendor/phpmailer/phpmailer/src/SMTP.php',
            'tracker/vendor/phpspec/prophecy/CHANGES.md',
            'tracker/vendor/phpspec/prophecy/LICENSE',
            'tracker/vendor/phpspec/prophecy/README.md',
            'tracker/vendor/phpspec/prophecy/composer.json',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/ArgumentsWildcard.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/AnyValueToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/AnyValuesToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/ApproximateValueToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/ArrayCountToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/ArrayEntryToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/ArrayEveryEntryToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/CallbackToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/ExactValueToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/IdenticalValueToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/LogicalAndToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/LogicalNotToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/ObjectStateToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/StringContainsToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/TokenInterface.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Argument/Token/TypeToken.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Call/Call.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Call/CallCenter.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Comparator/ClosureComparator.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Comparator/Factory.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Comparator/ProphecyComparator.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/CachedDoubler.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/ClassPatch/ClassPatchInterface.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/ClassPatch/DisableConstructorPatch.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/ClassPatch/HhvmExceptionPatch.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/ClassPatch/KeywordPatch.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/ClassPatch/MagicCallPatch.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/ClassPatch/ProphecySubjectPatch.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/ClassPatch/ReflectionClassNewInstancePatch.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/ClassPatch/SplFileInfoPatch.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/ClassPatch/ThrowablePatch.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/ClassPatch/TraversablePatch.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/DoubleInterface.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/Doubler.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/Generator/ClassCodeGenerator.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/Generator/ClassCreator.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/Generator/ClassMirror.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/Generator/Node/ArgumentNode.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/Generator/Node/ClassNode.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/Generator/Node/MethodNode.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/Generator/ReflectionInterface.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/Generator/TypeHintReference.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/LazyDouble.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Doubler/NameGenerator.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Call/UnexpectedCallException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Doubler/ClassCreatorException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Doubler/ClassMirrorException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Doubler/ClassNotFoundException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Doubler/DoubleException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Doubler/DoublerException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Doubler/InterfaceNotFoundException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Doubler/MethodNotExtendableException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Doubler/MethodNotFoundException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Doubler/ReturnByReferenceException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Exception.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/InvalidArgumentException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Prediction/AggregateException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Prediction/FailedPredictionException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Prediction/NoCallsException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Prediction/PredictionException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Prediction/UnexpectedCallsCountException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Prediction/UnexpectedCallsException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Prophecy/MethodProphecyException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Prophecy/ObjectProphecyException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Exception/Prophecy/ProphecyException.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/PhpDocumentor/ClassAndInterfaceTagRetriever.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/PhpDocumentor/ClassTagRetriever.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/PhpDocumentor/LegacyClassTagRetriever.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/PhpDocumentor/MethodTagRetrieverInterface.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Prediction/CallPrediction.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Prediction/CallTimesPrediction.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Prediction/CallbackPrediction.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Prediction/NoCallsPrediction.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Prediction/PredictionInterface.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Promise/CallbackPromise.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Promise/PromiseInterface.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Promise/ReturnArgumentPromise.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Promise/ReturnPromise.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Promise/ThrowPromise.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Prophecy/MethodProphecy.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Prophecy/ObjectProphecy.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Prophecy/ProphecyInterface.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Prophecy/ProphecySubjectInterface.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Prophecy/Revealer.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Prophecy/RevealerInterface.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Prophet.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Util/ExportUtil.php',
            'tracker/vendor/phpspec/prophecy/src/Prophecy/Util/StringUtil.php',
            'tracker/vendor/phpunit/php-code-coverage/.gitattributes',
            'tracker/vendor/phpunit/php-code-coverage/.gitignore',
            'tracker/vendor/phpunit/php-code-coverage/.travis.yml',
            'tracker/vendor/phpunit/php-code-coverage/CONTRIBUTING.md',
            'tracker/vendor/phpunit/php-code-coverage/ChangeLog-2.2.md',
            'tracker/vendor/phpunit/php-code-coverage/LICENSE',
            'tracker/vendor/phpunit/php-code-coverage/README.md',
            'tracker/vendor/phpunit/php-code-coverage/build.xml',
            'tracker/vendor/phpunit/php-code-coverage/build/travis-ci.xml',
            'tracker/vendor/phpunit/php-code-coverage/composer.json',
            'tracker/vendor/phpunit/php-code-coverage/phpunit.xml.dist',
            'tracker/vendor/phpunit/php-code-coverage/scripts/auto_append.php',
            'tracker/vendor/phpunit/php-code-coverage/scripts/auto_prepend.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Driver.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Driver/HHVM.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Driver/PHPDBG.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Driver/Xdebug.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Exception.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Exception/UnintentionallyCoveredCode.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Filter.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/Clover.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/Crap4j.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/Factory.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Dashboard.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Directory.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/File.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/coverage_bar.html.dist',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/css/bootstrap.min.css',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/css/nv.d3.min.css',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/css/style.css',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/dashboard.html.dist',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/directory.html.dist',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/directory_item.html.dist',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/file.html.dist',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/file_item.html.dist',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/fonts/glyphicons-halflings-regular.eot',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/fonts/glyphicons-halflings-regular.svg',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/fonts/glyphicons-halflings-regular.ttf',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/fonts/glyphicons-halflings-regular.woff',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/fonts/glyphicons-halflings-regular.woff2',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/js/bootstrap.min.js',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/js/d3.min.js',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/js/holder.min.js',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/js/html5shiv.min.js',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/js/jquery.min.js',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/js/nv.d3.min.js',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/js/respond.min.js',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/HTML/Renderer/Template/method_item.html.dist',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/Node.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/Node/Directory.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/Node/File.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/Node/Iterator.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/PHP.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/Text.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/XML.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/XML/Directory.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/XML/File.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/XML/File/Coverage.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/XML/File/Method.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/XML/File/Report.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/XML/File/Unit.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/XML/Node.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/XML/Project.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/XML/Tests.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Report/XML/Totals.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Util.php',
            'tracker/vendor/phpunit/php-code-coverage/src/CodeCoverage/Util/InvalidArgumentHelper.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/PHP/CodeCoverage/FilterTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/PHP/CodeCoverage/Report/CloverTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/PHP/CodeCoverage/Report/FactoryTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/PHP/CodeCoverage/UtilTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/PHP/CodeCoverageTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/TestCase.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/BankAccount-clover.xml',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/BankAccount.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/BankAccountTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageClassExtendedTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageClassTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageFunctionParenthesesTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageFunctionParenthesesWhitespaceTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageFunctionTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageMethodOneLineAnnotationTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageMethodParenthesesTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageMethodParenthesesWhitespaceTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageMethodTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageNoneTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageNotPrivateTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageNotProtectedTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageNotPublicTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageNothingTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoveragePrivateTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageProtectedTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoveragePublicTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoverageTwoDefaultClassAnnotations.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoveredClass.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/CoveredFunction.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/NamespaceCoverageClassExtendedTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/NamespaceCoverageClassTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/NamespaceCoverageCoversClassPublicTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/NamespaceCoverageCoversClassTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/NamespaceCoverageMethodTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/NamespaceCoverageNotPrivateTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/NamespaceCoverageNotProtectedTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/NamespaceCoverageNotPublicTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/NamespaceCoveragePrivateTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/NamespaceCoverageProtectedTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/NamespaceCoveragePublicTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/NamespaceCoveredClass.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/NotExistingCoveredElementTest.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/class-with-anonymous-function-clover.xml',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/ignored-lines-clover.xml',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/source_with_class_and_anonymous_function.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/source_with_ignore.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/source_with_namespace.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/source_with_oneline_annotations.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/source_without_ignore.php',
            'tracker/vendor/phpunit/php-code-coverage/tests/_files/source_without_namespace.php',
            'tracker/vendor/phpunit/php-file-iterator/.gitattributes',
            'tracker/vendor/phpunit/php-file-iterator/.gitignore',
            'tracker/vendor/phpunit/php-file-iterator/ChangeLog.md',
            'tracker/vendor/phpunit/php-file-iterator/LICENSE',
            'tracker/vendor/phpunit/php-file-iterator/README.md',
            'tracker/vendor/phpunit/php-file-iterator/composer.json',
            'tracker/vendor/phpunit/php-file-iterator/src/Facade.php',
            'tracker/vendor/phpunit/php-file-iterator/src/Factory.php',
            'tracker/vendor/phpunit/php-file-iterator/src/Iterator.php',
            'tracker/vendor/phpunit/php-text-template/.gitattributes',
            'tracker/vendor/phpunit/php-text-template/.gitignore',
            'tracker/vendor/phpunit/php-text-template/LICENSE',
            'tracker/vendor/phpunit/php-text-template/README.md',
            'tracker/vendor/phpunit/php-text-template/composer.json',
            'tracker/vendor/phpunit/php-text-template/src/Template.php',
            'tracker/vendor/phpunit/php-timer/.gitattributes',
            'tracker/vendor/phpunit/php-timer/.gitignore',
            'tracker/vendor/phpunit/php-timer/.travis.yml',
            'tracker/vendor/phpunit/php-timer/LICENSE',
            'tracker/vendor/phpunit/php-timer/README.md',
            'tracker/vendor/phpunit/php-timer/composer.json',
            'tracker/vendor/phpunit/php-timer/phpunit.xml',
            'tracker/vendor/phpunit/php-timer/src/Timer.php',
            'tracker/vendor/phpunit/php-timer/tests/TimerTest.php',
            'tracker/vendor/phpunit/php-token-stream/.gitattributes',
            'tracker/vendor/phpunit/php-token-stream/.gitignore',
            'tracker/vendor/phpunit/php-token-stream/.travis.yml',
            'tracker/vendor/phpunit/php-token-stream/LICENSE',
            'tracker/vendor/phpunit/php-token-stream/README.md',
            'tracker/vendor/phpunit/php-token-stream/build.xml',
            'tracker/vendor/phpunit/php-token-stream/build/phpunit.xml',
            'tracker/vendor/phpunit/php-token-stream/composer.json',
            'tracker/vendor/phpunit/php-token-stream/src/Token.php',
            'tracker/vendor/phpunit/php-token-stream/src/Token/Stream.php',
            'tracker/vendor/phpunit/php-token-stream/src/Token/Stream/CachingFactory.php',
            'tracker/vendor/phpunit/php-token-stream/tests/Token/ClassTest.php',
            'tracker/vendor/phpunit/php-token-stream/tests/Token/ClosureTest.php',
            'tracker/vendor/phpunit/php-token-stream/tests/Token/FunctionTest.php',
            'tracker/vendor/phpunit/php-token-stream/tests/Token/IncludeTest.php',
            'tracker/vendor/phpunit/php-token-stream/tests/Token/InterfaceTest.php',
            'tracker/vendor/phpunit/php-token-stream/tests/Token/NamespaceTest.php',
            'tracker/vendor/phpunit/php-token-stream/tests/TokenTest.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/classExtendsNamespacedClass.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/classInNamespace.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/classInScopedNamespace.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/classUsesNamespacedFunction.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/class_with_method_that_declares_anonymous_class.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/class_with_method_that_declares_anonymous_class2.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/closure.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/issue19.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/issue30.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/multipleNamespacesWithOneClassUsingBraces.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/multipleNamespacesWithOneClassUsingNonBraceSyntax.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/source.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/source2.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/source3.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/source4.php',
            'tracker/vendor/phpunit/php-token-stream/tests/_fixture/source5.php',
            'tracker/vendor/phpunit/php-token-stream/tests/bootstrap.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/.gitattributes',
            'tracker/vendor/phpunit/phpunit-mock-objects/.gitignore',
            'tracker/vendor/phpunit/phpunit-mock-objects/.travis.yml',
            'tracker/vendor/phpunit/phpunit-mock-objects/CONTRIBUTING.md',
            'tracker/vendor/phpunit/phpunit-mock-objects/LICENSE',
            'tracker/vendor/phpunit/phpunit-mock-objects/README.md',
            'tracker/vendor/phpunit/phpunit-mock-objects/build.xml',
            'tracker/vendor/phpunit/phpunit-mock-objects/build/travis-ci.xml',
            'tracker/vendor/phpunit/phpunit-mock-objects/composer.json',
            'tracker/vendor/phpunit/phpunit-mock-objects/phpunit.xml.dist',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Builder/Identity.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Builder/InvocationMocker.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Builder/Match.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Builder/MethodNameMatch.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Builder/Namespace.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Builder/ParametersMatch.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Builder/Stub.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Exception/BadMethodCallException.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Exception/Exception.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Exception/RuntimeException.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Generator.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Generator/mocked_class.tpl.dist',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Generator/mocked_class_method.tpl.dist',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Generator/mocked_clone.tpl.dist',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Generator/mocked_method.tpl.dist',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Generator/mocked_static_method.tpl.dist',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Generator/proxied_method.tpl.dist',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Generator/trait_class.tpl.dist',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Generator/unmocked_clone.tpl.dist',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Generator/wsdl_class.tpl.dist',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Generator/wsdl_method.tpl.dist',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Invocation.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Invocation/Object.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Invocation/Static.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/InvocationMocker.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Invokable.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher/AnyInvokedCount.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher/AnyParameters.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher/ConsecutiveParameters.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher/Invocation.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher/InvokedAtIndex.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher/InvokedAtLeastCount.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher/InvokedAtLeastOnce.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher/InvokedAtMostCount.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher/InvokedCount.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher/InvokedRecorder.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher/MethodName.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher/Parameters.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Matcher/StatelessInvocation.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/MockBuilder.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/MockObject.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Stub.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Stub/ConsecutiveCalls.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Stub/Exception.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Stub/MatcherCollection.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Stub/Return.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Stub/ReturnArgument.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Stub/ReturnCallback.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Stub/ReturnSelf.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Stub/ReturnValueMap.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/src/Framework/MockObject/Verifiable.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/GeneratorTest.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockBuilderTest.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/232.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/Invocation/ObjectTest.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/Invocation/StaticTest.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/Matcher/ConsecutiveParametersTest.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/abstract_class.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/class.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/class_call_parent_clone.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/class_call_parent_constructor.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/class_dont_call_parent_clone.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/class_dont_call_parent_constructor.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/class_implementing_interface_call_parent_constructor.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/class_implementing_interface_dont_call_parent_constructor.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/class_partial.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/class_with_method_named_method.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/class_with_method_with_variadic_arguments.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/interface.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/invocation_object_clone_object.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/namespaced_class.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/namespaced_class_call_parent_clone.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/namespaced_class_call_parent_constructor.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/namespaced_class_dont_call_parent_clone.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/namespaced_class_dont_call_parent_constructor.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/namespaced_class_implementing_interface_call_parent_constructor.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/namespaced_class_implementing_interface_dont_call_parent_constructor.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/namespaced_class_partial.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/namespaced_interface.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/nonexistent_class.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/nonexistent_class_with_namespace.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/nonexistent_class_with_namespace_starting_with_separator.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/proxy.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/scalar_type_declarations.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/wsdl_class.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/wsdl_class_namespace.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObject/wsdl_class_partial.phpt',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/MockObjectTest.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/ProxyObjectTest.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/AbstractMockTestClass.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/AbstractTrait.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/AnInterface.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/AnotherInterface.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/Bar.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/ClassThatImplementsSerializable.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/ClassWithStaticMethod.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/Foo.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/FunctionCallback.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/GoogleSearch.wsdl',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/InterfaceWithStaticMethod.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/MethodCallback.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/MethodCallbackByReference.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/MockTestInterface.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/Mockable.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/PartialMockTestClass.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/SingletonClass.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/SomeClass.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/StaticMockTestClass.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/_fixture/TraversableMockTestInterface.php',
            'tracker/vendor/phpunit/phpunit-mock-objects/tests/bootstrap.php',
            'tracker/vendor/phpunit/phpunit/.gitattributes',
            'tracker/vendor/phpunit/phpunit/.gitignore',
            'tracker/vendor/phpunit/phpunit/.php_cs',
            'tracker/vendor/phpunit/phpunit/.travis.yml',
            'tracker/vendor/phpunit/phpunit/CODE_OF_CONDUCT.md',
            'tracker/vendor/phpunit/phpunit/CONTRIBUTING.md',
            'tracker/vendor/phpunit/phpunit/ChangeLog-4.0.md',
            'tracker/vendor/phpunit/phpunit/ChangeLog-4.1.md',
            'tracker/vendor/phpunit/phpunit/ChangeLog-4.2.md',
            'tracker/vendor/phpunit/phpunit/ChangeLog-4.3.md',
            'tracker/vendor/phpunit/phpunit/ChangeLog-4.4.md',
            'tracker/vendor/phpunit/phpunit/ChangeLog-4.5.md',
            'tracker/vendor/phpunit/phpunit/ChangeLog-4.6.md',
            'tracker/vendor/phpunit/phpunit/ChangeLog-4.7.md',
            'tracker/vendor/phpunit/phpunit/ChangeLog-4.8.md',
            'tracker/vendor/phpunit/phpunit/LICENSE',
            'tracker/vendor/phpunit/phpunit/README.md',
            'tracker/vendor/phpunit/phpunit/build.xml',
            'tracker/vendor/phpunit/phpunit/composer.json',
            'tracker/vendor/phpunit/phpunit/phpunit',
            'tracker/vendor/phpunit/phpunit/phpunit.xml',
            'tracker/vendor/phpunit/phpunit/phpunit.xsd',
            'tracker/vendor/phpunit/phpunit/src/Exception.php',
            'tracker/vendor/phpunit/phpunit/src/Extensions/GroupTestSuite.php',
            'tracker/vendor/phpunit/phpunit/src/Extensions/PhptTestCase.php',
            'tracker/vendor/phpunit/phpunit/src/Extensions/PhptTestSuite.php',
            'tracker/vendor/phpunit/phpunit/src/Extensions/RepeatedTest.php',
            'tracker/vendor/phpunit/phpunit/src/Extensions/TestDecorator.php',
            'tracker/vendor/phpunit/phpunit/src/Extensions/TicketListener.php',
            'tracker/vendor/phpunit/phpunit/src/ForwardCompatibility/Assert.php',
            'tracker/vendor/phpunit/phpunit/src/ForwardCompatibility/AssertionFailedError.php',
            'tracker/vendor/phpunit/phpunit/src/ForwardCompatibility/BaseTestListener.php',
            'tracker/vendor/phpunit/phpunit/src/ForwardCompatibility/Test.php',
            'tracker/vendor/phpunit/phpunit/src/ForwardCompatibility/TestCase.php',
            'tracker/vendor/phpunit/phpunit/src/ForwardCompatibility/TestListener.php',
            'tracker/vendor/phpunit/phpunit/src/ForwardCompatibility/TestSuite.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Assert.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Assert/Functions.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/AssertionFailedError.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/BaseTestListener.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/CodeCoverageException.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/And.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/ArrayHasKey.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/ArraySubset.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/Attribute.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/Callback.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/ClassHasAttribute.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/ClassHasStaticAttribute.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/Composite.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/Count.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/Exception.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/ExceptionCode.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/ExceptionMessage.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/ExceptionMessageRegExp.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/FileExists.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/GreaterThan.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/IsAnything.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/IsEmpty.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/IsEqual.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/IsFalse.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/IsIdentical.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/IsInstanceOf.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/IsJson.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/IsNull.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/IsTrue.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/IsType.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/JsonMatches.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/JsonMatches/ErrorMessageProvider.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/LessThan.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/Not.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/ObjectHasAttribute.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/Or.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/PCREMatch.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/SameSize.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/StringContains.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/StringEndsWith.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/StringMatches.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/StringStartsWith.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/TraversableContains.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/TraversableContainsOnly.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Constraint/Xor.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Error.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Error/Deprecated.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Error/Notice.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Error/Warning.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Exception.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/ExceptionWrapper.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/ExpectationFailedException.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/IncompleteTest.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/IncompleteTestCase.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/IncompleteTestError.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/InvalidCoversTargetError.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/InvalidCoversTargetException.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/OutputError.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/RiskyTest.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/RiskyTestError.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/SelfDescribing.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/SkippedTest.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/SkippedTestCase.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/SkippedTestError.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/SkippedTestSuiteError.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/SyntheticError.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Test.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/TestCase.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/TestFailure.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/TestListener.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/TestResult.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/TestSuite.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/TestSuite/DataProvider.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/UnintentionallyCoveredCodeError.php',
            'tracker/vendor/phpunit/phpunit/src/Framework/Warning.php',
            'tracker/vendor/phpunit/phpunit/src/Runner/BaseTestRunner.php',
            'tracker/vendor/phpunit/phpunit/src/Runner/Exception.php',
            'tracker/vendor/phpunit/phpunit/src/Runner/Filter/Factory.php',
            'tracker/vendor/phpunit/phpunit/src/Runner/Filter/Group.php',
            'tracker/vendor/phpunit/phpunit/src/Runner/Filter/Group/Exclude.php',
            'tracker/vendor/phpunit/phpunit/src/Runner/Filter/Group/Include.php',
            'tracker/vendor/phpunit/phpunit/src/Runner/Filter/Test.php',
            'tracker/vendor/phpunit/phpunit/src/Runner/StandardTestSuiteLoader.php',
            'tracker/vendor/phpunit/phpunit/src/Runner/TestSuiteLoader.php',
            'tracker/vendor/phpunit/phpunit/src/Runner/Version.php',
            'tracker/vendor/phpunit/phpunit/src/TextUI/Command.php',
            'tracker/vendor/phpunit/phpunit/src/TextUI/ResultPrinter.php',
            'tracker/vendor/phpunit/phpunit/src/TextUI/TestRunner.php',
            'tracker/vendor/phpunit/phpunit/src/Util/Blacklist.php',
            'tracker/vendor/phpunit/phpunit/src/Util/Configuration.php',
            'tracker/vendor/phpunit/phpunit/src/Util/ErrorHandler.php',
            'tracker/vendor/phpunit/phpunit/src/Util/Fileloader.php',
            'tracker/vendor/phpunit/phpunit/src/Util/Filesystem.php',
            'tracker/vendor/phpunit/phpunit/src/Util/Filter.php',
            'tracker/vendor/phpunit/phpunit/src/Util/Getopt.php',
            'tracker/vendor/phpunit/phpunit/src/Util/GlobalState.php',
            'tracker/vendor/phpunit/phpunit/src/Util/InvalidArgumentHelper.php',
            'tracker/vendor/phpunit/phpunit/src/Util/Log/JSON.php',
            'tracker/vendor/phpunit/phpunit/src/Util/Log/JUnit.php',
            'tracker/vendor/phpunit/phpunit/src/Util/Log/TAP.php',
            'tracker/vendor/phpunit/phpunit/src/Util/PHP.php',
            'tracker/vendor/phpunit/phpunit/src/Util/PHP/Default.php',
            'tracker/vendor/phpunit/phpunit/src/Util/PHP/Template/TestCaseMethod.tpl.dist',
            'tracker/vendor/phpunit/phpunit/src/Util/PHP/Windows.php',
            'tracker/vendor/phpunit/phpunit/src/Util/PHP/eval-stdin.php',
            'tracker/vendor/phpunit/phpunit/src/Util/Printer.php',
            'tracker/vendor/phpunit/phpunit/src/Util/Regex.php',
            'tracker/vendor/phpunit/phpunit/src/Util/String.php',
            'tracker/vendor/phpunit/phpunit/src/Util/Test.php',
            'tracker/vendor/phpunit/phpunit/src/Util/TestDox/NamePrettifier.php',
            'tracker/vendor/phpunit/phpunit/src/Util/TestDox/ResultPrinter.php',
            'tracker/vendor/phpunit/phpunit/src/Util/TestDox/ResultPrinter/HTML.php',
            'tracker/vendor/phpunit/phpunit/src/Util/TestDox/ResultPrinter/Text.php',
            'tracker/vendor/phpunit/phpunit/src/Util/TestSuiteIterator.php',
            'tracker/vendor/phpunit/phpunit/src/Util/Type.php',
            'tracker/vendor/phpunit/phpunit/src/Util/XML.php',
            'tracker/vendor/phpunit/phpunit/tests/Extensions/PhptTestCaseTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Extensions/RepeatedTestTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Fail/fail.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Framework/AssertTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Framework/BaseTestListenerTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Framework/Constraint/CountTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Framework/Constraint/ExceptionMessageRegExpTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Framework/Constraint/ExceptionMessageTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Framework/Constraint/JsonMatches/ErrorMessageProviderTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Framework/Constraint/JsonMatchesTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Framework/ConstraintTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Framework/SuiteTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Framework/TestCaseTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Framework/TestFailureTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Framework/TestImplementorTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Framework/TestListenerTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1149.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1149/Issue1149Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1216.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1216/Issue1216Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1216/bootstrap1216.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1216/phpunit1216.xml',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1265.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1265/Issue1265Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1265/phpunit1265.xml',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1330.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1330/Issue1330Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1330/phpunit1330.xml',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1335.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1335/Issue1335Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1335/bootstrap1335.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1337.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1337/Issue1337Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1348.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1348/Issue1348Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1351.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1351/ChildProcessClass1351.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1351/Issue1351Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1374.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1374/Issue1374Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1437.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1437/Issue1437Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1468.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1468/Issue1468Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1471.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1471/Issue1471Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1472.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1472/Issue1472Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1570.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/1570/Issue1570Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/2158.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/2158/Issue2158Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/2158/constant.inc',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/244.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/244/Issue244Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/322.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/322/Issue322Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/322/phpunit322.xml',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/433.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/433/Issue433Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/445.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/445/Issue445Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/498.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/498/Issue498Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/503.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/503/Issue503Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/581.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/581/Issue581Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/74.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/74/Issue74Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/74/NewException.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/765.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/765/Issue765Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/797.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/797/Issue797Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/797/bootstrap797.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/863.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/873-php5.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/873-php7.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/GitHub/873/Issue873Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/Trac/1021.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/Trac/1021/Issue1021Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/Trac/523.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/Trac/523/Issue523Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/Trac/578.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/Trac/578/Issue578Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/Trac/684.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/Trac/684/Issue684Test.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/Trac/783.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Regression/Trac/783/ChildSuite.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/Trac/783/OneTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/Trac/783/ParentSuite.php',
            'tracker/vendor/phpunit/phpunit/tests/Regression/Trac/783/TwoTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Runner/BaseTestRunnerTest.php',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/abstract-test-class.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/colors-always.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/concrete-test-class.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/custom-printer-debug.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/custom-printer-verbose.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/dataprovider-debug.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/dataprovider-log-xml-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/dataprovider-log-xml.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/dataprovider-testdox.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/debug.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/default-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/default.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/dependencies-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/dependencies.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/dependencies2-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/dependencies2.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/dependencies3-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/dependencies3.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/empty-testcase.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/exception-stack.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/exclude-group-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/exclude-group.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/failure-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/failure.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/fatal-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-class-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-class.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-classname-and-range-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-classname-and-range.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-number-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-number.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-only-range-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-only-range.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-only-regexp-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-only-regexp.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-only-string-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-only-string.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-range-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-range.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-regexp-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-regexp.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-string-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-dataprovider-by-string.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-method-case-insensitive.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-method-case-sensitive-no-result.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-method-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-method.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/filter-no-results.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/group-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/group.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/help.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/help2.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/ini-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/list-groups.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/log-json-no-pretty-print.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/log-json-post-66021.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/log-json-pre-66021.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/log-junit.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/log-tap.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/options-after-arguments.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/output-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/repeat.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/report-useless-tests-incomplete.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/report-useless-tests-isolation.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/report-useless-tests.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/tap.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/test-suffix-multiple.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/test-suffix-single.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/testdox-html.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/testdox-text.phpt',
            'tracker/vendor/phpunit/phpunit/tests/TextUI/testdox.phpt',
            'tracker/vendor/phpunit/phpunit/tests/Util/ConfigurationTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Util/GetoptTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Util/GlobalStateTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Util/RegexTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Util/TestDox/NamePrettifierTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Util/TestTest.php',
            'tracker/vendor/phpunit/phpunit/tests/Util/XMLTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/AbstractTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/Author.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/BankAccount.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/BankAccountTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/BankAccountTest.test.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/BaseTestListenerSample.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/BeforeAndAfterTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/BeforeClassAndAfterClassTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/Book.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/Calculator.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ChangeCurrentWorkingDirectoryTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ClassWithNonPublicAttributes.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ClassWithScalarTypeDeclarations.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ClassWithToString.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ConcreteTest.my.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ConcreteTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageClassExtendedTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageClassTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageFunctionParenthesesTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageFunctionParenthesesWhitespaceTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageFunctionTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageMethodOneLineAnnotationTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageMethodParenthesesTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageMethodParenthesesWhitespaceTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageMethodTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageNamespacedFunctionTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageNoneTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageNotPrivateTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageNotProtectedTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageNotPublicTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageNothingTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoveragePrivateTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageProtectedTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoveragePublicTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoverageTwoDefaultClassAnnotations.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoveredClass.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CoveredFunction.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/CustomPrinter.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/DataProviderDebugTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/DataProviderFilterTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/DataProviderIncompleteTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/DataProviderSkippedTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/DataProviderTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/DependencyFailureTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/DependencySuccessTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/DependencyTestSuite.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/DoubleTestCase.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/DummyException.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/EmptyTestCaseTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ExceptionInAssertPostConditionsTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ExceptionInAssertPreConditionsTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ExceptionInSetUpTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ExceptionInTearDownTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ExceptionInTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ExceptionNamespaceTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ExceptionStackTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ExceptionTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/Failure.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/FailureTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/FatalTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/IncompleteTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/Inheritance/InheritanceA.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/Inheritance/InheritanceB.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/InheritedTestCase.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/IniTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/IsolationTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/JsonData/arrayObject.json',
            'tracker/vendor/phpunit/phpunit/tests/_files/JsonData/simpleObject.json',
            'tracker/vendor/phpunit/phpunit/tests/_files/MockRunner.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/MultiDependencyTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NamespaceCoverageClassExtendedTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NamespaceCoverageClassTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NamespaceCoverageCoversClassPublicTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NamespaceCoverageCoversClassTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NamespaceCoverageMethodTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NamespaceCoverageNotPrivateTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NamespaceCoverageNotProtectedTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NamespaceCoverageNotPublicTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NamespaceCoveragePrivateTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NamespaceCoverageProtectedTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NamespaceCoveragePublicTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NamespaceCoveredClass.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NamespaceCoveredFunction.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NoArgTestCaseTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NoTestCaseClass.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NoTestCases.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NonStatic.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NotExistingCoveredElementTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NotPublicTestCase.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NotVoidTestCase.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/NothingTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/OneTestCase.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/OutputTestCase.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/OverrideTestCase.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/RequirementsClassBeforeClassHookTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/RequirementsClassDocBlockTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/RequirementsTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/SampleArrayAccess.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/SampleClass.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/Singleton.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/StackTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/StatusTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/Struct.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/Success.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/TemplateMethodsTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/TestIncomplete.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/TestIterator.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/TestIterator2.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/TestSkipped.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/TestTestError.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/TestWithTest.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ThrowExceptionTestCase.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/ThrowNoExceptionTestCase.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/WasRun.php',
            'tracker/vendor/phpunit/phpunit/tests/_files/bar.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/configuration.colors.empty.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/configuration.colors.false.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/configuration.colors.invalid.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/configuration.colors.true.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/configuration.custom-printer.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/configuration.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/configuration_empty.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/configuration_xinclude.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/expectedFileFormat.txt',
            'tracker/vendor/phpunit/phpunit/tests/_files/foo.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/structureAttributesAreSameButValuesAreNot.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/structureExpected.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/structureIgnoreTextNodes.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/structureIsSameButDataIsNot.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/structureWrongNumberOfAttributes.xml',
            'tracker/vendor/phpunit/phpunit/tests/_files/structureWrongNumberOfNodes.xml',
            'tracker/vendor/phpunit/phpunit/tests/bootstrap.php',
            'tracker/vendor/pimple/pimple/.gitignore',
            'tracker/vendor/pimple/pimple/.travis.yml',
            'tracker/vendor/pimple/pimple/CHANGELOG',
            'tracker/vendor/pimple/pimple/LICENSE',
            'tracker/vendor/pimple/pimple/README.rst',
            'tracker/vendor/pimple/pimple/composer.json',
            'tracker/vendor/pimple/pimple/ext/pimple/.gitignore',
            'tracker/vendor/pimple/pimple/ext/pimple/README.md',
            'tracker/vendor/pimple/pimple/ext/pimple/config.m4',
            'tracker/vendor/pimple/pimple/ext/pimple/config.w32',
            'tracker/vendor/pimple/pimple/ext/pimple/php_pimple.h',
            'tracker/vendor/pimple/pimple/ext/pimple/pimple.c',
            'tracker/vendor/pimple/pimple/ext/pimple/pimple_compat.h',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/001.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/002.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/003.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/004.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/005.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/006.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/007.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/008.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/009.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/010.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/011.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/012.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/013.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/014.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/015.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/016.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/017.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/017_1.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/018.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/019.phpt',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/bench.phpb',
            'tracker/vendor/pimple/pimple/ext/pimple/tests/bench_shared.phpb',
            'tracker/vendor/pimple/pimple/phpunit.xml.dist',
            'tracker/vendor/pimple/pimple/src/Pimple/Container.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Exception/ExpectedInvokableException.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Exception/FrozenServiceException.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Exception/InvalidServiceIdentifierException.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Exception/UnknownIdentifierException.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Psr11/Container.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Psr11/ServiceLocator.php',
            'tracker/vendor/pimple/pimple/src/Pimple/ServiceIterator.php',
            'tracker/vendor/pimple/pimple/src/Pimple/ServiceProviderInterface.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Tests/Fixtures/Invokable.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Tests/Fixtures/NonInvokable.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Tests/Fixtures/PimpleServiceProvider.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Tests/Fixtures/Service.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Tests/PimpleServiceProviderInterfaceTest.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Tests/PimpleTest.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Tests/Psr11/ContainerTest.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Tests/Psr11/ServiceLocatorTest.php',
            'tracker/vendor/pimple/pimple/src/Pimple/Tests/ServiceIteratorTest.php',
            'tracker/vendor/psr/container/.gitignore',
            'tracker/vendor/psr/container/LICENSE',
            'tracker/vendor/psr/container/README.md',
            'tracker/vendor/psr/container/composer.json',
            'tracker/vendor/psr/container/src/ContainerExceptionInterface.php',
            'tracker/vendor/psr/container/src/ContainerInterface.php',
            'tracker/vendor/psr/container/src/NotFoundExceptionInterface.php',
            'tracker/vendor/psr/http-message/CHANGELOG.md',
            'tracker/vendor/psr/http-message/LICENSE',
            'tracker/vendor/psr/http-message/README.md',
            'tracker/vendor/psr/http-message/composer.json',
            'tracker/vendor/psr/http-message/src/MessageInterface.php',
            'tracker/vendor/psr/http-message/src/RequestInterface.php',
            'tracker/vendor/psr/http-message/src/ResponseInterface.php',
            'tracker/vendor/psr/http-message/src/ServerRequestInterface.php',
            'tracker/vendor/psr/http-message/src/StreamInterface.php',
            'tracker/vendor/psr/http-message/src/UploadedFileInterface.php',
            'tracker/vendor/psr/http-message/src/UriInterface.php',
            'tracker/vendor/ralouphie/getallheaders/.gitignore',
            'tracker/vendor/ralouphie/getallheaders/.travis.yml',
            'tracker/vendor/ralouphie/getallheaders/LICENSE',
            'tracker/vendor/ralouphie/getallheaders/README.md',
            'tracker/vendor/ralouphie/getallheaders/composer.json',
            'tracker/vendor/ralouphie/getallheaders/phpunit.xml',
            'tracker/vendor/ralouphie/getallheaders/src/getallheaders.php',
            'tracker/vendor/ralouphie/getallheaders/tests/GetAllHeadersTest.php',
            'tracker/vendor/sebastian/comparator/.gitignore',
            'tracker/vendor/sebastian/comparator/.travis.yml',
            'tracker/vendor/sebastian/comparator/LICENSE',
            'tracker/vendor/sebastian/comparator/README.md',
            'tracker/vendor/sebastian/comparator/build.xml',
            'tracker/vendor/sebastian/comparator/build/travis-ci.xml',
            'tracker/vendor/sebastian/comparator/composer.json',
            'tracker/vendor/sebastian/comparator/phpunit.xml.dist',
            'tracker/vendor/sebastian/comparator/src/ArrayComparator.php',
            'tracker/vendor/sebastian/comparator/src/Comparator.php',
            'tracker/vendor/sebastian/comparator/src/ComparisonFailure.php',
            'tracker/vendor/sebastian/comparator/src/DOMNodeComparator.php',
            'tracker/vendor/sebastian/comparator/src/DateTimeComparator.php',
            'tracker/vendor/sebastian/comparator/src/DoubleComparator.php',
            'tracker/vendor/sebastian/comparator/src/ExceptionComparator.php',
            'tracker/vendor/sebastian/comparator/src/Factory.php',
            'tracker/vendor/sebastian/comparator/src/MockObjectComparator.php',
            'tracker/vendor/sebastian/comparator/src/NumericComparator.php',
            'tracker/vendor/sebastian/comparator/src/ObjectComparator.php',
            'tracker/vendor/sebastian/comparator/src/ResourceComparator.php',
            'tracker/vendor/sebastian/comparator/src/ScalarComparator.php',
            'tracker/vendor/sebastian/comparator/src/SplObjectStorageComparator.php',
            'tracker/vendor/sebastian/comparator/src/TypeComparator.php',
            'tracker/vendor/sebastian/comparator/tests/ArrayComparatorTest.php',
            'tracker/vendor/sebastian/comparator/tests/DOMNodeComparatorTest.php',
            'tracker/vendor/sebastian/comparator/tests/DateTimeComparatorTest.php',
            'tracker/vendor/sebastian/comparator/tests/DoubleComparatorTest.php',
            'tracker/vendor/sebastian/comparator/tests/ExceptionComparatorTest.php',
            'tracker/vendor/sebastian/comparator/tests/FactoryTest.php',
            'tracker/vendor/sebastian/comparator/tests/MockObjectComparatorTest.php',
            'tracker/vendor/sebastian/comparator/tests/NumericComparatorTest.php',
            'tracker/vendor/sebastian/comparator/tests/ObjectComparatorTest.php',
            'tracker/vendor/sebastian/comparator/tests/ResourceComparatorTest.php',
            'tracker/vendor/sebastian/comparator/tests/ScalarComparatorTest.php',
            'tracker/vendor/sebastian/comparator/tests/SplObjectStorageComparatorTest.php',
            'tracker/vendor/sebastian/comparator/tests/TypeComparatorTest.php',
            'tracker/vendor/sebastian/comparator/tests/_files/Author.php',
            'tracker/vendor/sebastian/comparator/tests/_files/Book.php',
            'tracker/vendor/sebastian/comparator/tests/_files/ClassWithToString.php',
            'tracker/vendor/sebastian/comparator/tests/_files/SampleClass.php',
            'tracker/vendor/sebastian/comparator/tests/_files/Struct.php',
            'tracker/vendor/sebastian/comparator/tests/_files/TestClass.php',
            'tracker/vendor/sebastian/comparator/tests/_files/TestClassComparator.php',
            'tracker/vendor/sebastian/comparator/tests/autoload.php',
            'tracker/vendor/sebastian/comparator/tests/bootstrap.php',
            'tracker/vendor/sebastian/diff/.gitignore',
            'tracker/vendor/sebastian/diff/.php_cs',
            'tracker/vendor/sebastian/diff/.travis.yml',
            'tracker/vendor/sebastian/diff/LICENSE',
            'tracker/vendor/sebastian/diff/README.md',
            'tracker/vendor/sebastian/diff/build.xml',
            'tracker/vendor/sebastian/diff/composer.json',
            'tracker/vendor/sebastian/diff/phpunit.xml',
            'tracker/vendor/sebastian/diff/src/Chunk.php',
            'tracker/vendor/sebastian/diff/src/Diff.php',
            'tracker/vendor/sebastian/diff/src/Differ.php',
            'tracker/vendor/sebastian/diff/src/LCS/LongestCommonSubsequence.php',
            'tracker/vendor/sebastian/diff/src/LCS/MemoryEfficientLongestCommonSubsequenceImplementation.php',
            'tracker/vendor/sebastian/diff/src/LCS/TimeEfficientLongestCommonSubsequenceImplementation.php',
            'tracker/vendor/sebastian/diff/src/Line.php',
            'tracker/vendor/sebastian/diff/src/Parser.php',
            'tracker/vendor/sebastian/diff/tests/ChunkTest.php',
            'tracker/vendor/sebastian/diff/tests/DiffTest.php',
            'tracker/vendor/sebastian/diff/tests/DifferTest.php',
            'tracker/vendor/sebastian/diff/tests/LCS/LongestCommonSubsequenceTest.php',
            'tracker/vendor/sebastian/diff/tests/LCS/MemoryEfficientImplementationTest.php',
            'tracker/vendor/sebastian/diff/tests/LCS/TimeEfficientImplementationTest.php',
            'tracker/vendor/sebastian/diff/tests/LineTest.php',
            'tracker/vendor/sebastian/diff/tests/ParserTest.php',
            'tracker/vendor/sebastian/diff/tests/fixtures/patch.txt',
            'tracker/vendor/sebastian/diff/tests/fixtures/patch2.txt',
            'tracker/vendor/sebastian/environment/.gitignore',
            'tracker/vendor/sebastian/environment/.travis.yml',
            'tracker/vendor/sebastian/environment/LICENSE',
            'tracker/vendor/sebastian/environment/README.md',
            'tracker/vendor/sebastian/environment/build.xml',
            'tracker/vendor/sebastian/environment/composer.json',
            'tracker/vendor/sebastian/environment/phpunit.xml',
            'tracker/vendor/sebastian/environment/src/Console.php',
            'tracker/vendor/sebastian/environment/src/Runtime.php',
            'tracker/vendor/sebastian/environment/tests/ConsoleTest.php',
            'tracker/vendor/sebastian/environment/tests/RuntimeTest.php',
            'tracker/vendor/sebastian/exporter/.gitignore',
            'tracker/vendor/sebastian/exporter/.travis.yml',
            'tracker/vendor/sebastian/exporter/LICENSE',
            'tracker/vendor/sebastian/exporter/README.md',
            'tracker/vendor/sebastian/exporter/build.xml',
            'tracker/vendor/sebastian/exporter/composer.json',
            'tracker/vendor/sebastian/exporter/phpunit.xml.dist',
            'tracker/vendor/sebastian/exporter/src/Exporter.php',
            'tracker/vendor/sebastian/exporter/tests/ExporterTest.php',
            'tracker/vendor/sebastian/global-state/.gitignore',
            'tracker/vendor/sebastian/global-state/.travis.yml',
            'tracker/vendor/sebastian/global-state/LICENSE',
            'tracker/vendor/sebastian/global-state/README.md',
            'tracker/vendor/sebastian/global-state/build.xml',
            'tracker/vendor/sebastian/global-state/composer.json',
            'tracker/vendor/sebastian/global-state/phpunit.xml.dist',
            'tracker/vendor/sebastian/global-state/src/Blacklist.php',
            'tracker/vendor/sebastian/global-state/src/CodeExporter.php',
            'tracker/vendor/sebastian/global-state/src/Exception.php',
            'tracker/vendor/sebastian/global-state/src/Restorer.php',
            'tracker/vendor/sebastian/global-state/src/RuntimeException.php',
            'tracker/vendor/sebastian/global-state/src/Snapshot.php',
            'tracker/vendor/sebastian/global-state/tests/BlacklistTest.php',
            'tracker/vendor/sebastian/global-state/tests/SnapshotTest.php',
            'tracker/vendor/sebastian/global-state/tests/_fixture/BlacklistedChildClass.php',
            'tracker/vendor/sebastian/global-state/tests/_fixture/BlacklistedClass.php',
            'tracker/vendor/sebastian/global-state/tests/_fixture/BlacklistedImplementor.php',
            'tracker/vendor/sebastian/global-state/tests/_fixture/BlacklistedInterface.php',
            'tracker/vendor/sebastian/global-state/tests/_fixture/SnapshotClass.php',
            'tracker/vendor/sebastian/global-state/tests/_fixture/SnapshotDomDocument.php',
            'tracker/vendor/sebastian/global-state/tests/_fixture/SnapshotFunctions.php',
            'tracker/vendor/sebastian/global-state/tests/_fixture/SnapshotTrait.php',
            'tracker/vendor/sebastian/recursion-context/.gitignore',
            'tracker/vendor/sebastian/recursion-context/.travis.yml',
            'tracker/vendor/sebastian/recursion-context/LICENSE',
            'tracker/vendor/sebastian/recursion-context/README.md',
            'tracker/vendor/sebastian/recursion-context/build.xml',
            'tracker/vendor/sebastian/recursion-context/composer.json',
            'tracker/vendor/sebastian/recursion-context/phpunit.xml.dist',
            'tracker/vendor/sebastian/recursion-context/src/Context.php',
            'tracker/vendor/sebastian/recursion-context/src/Exception.php',
            'tracker/vendor/sebastian/recursion-context/src/InvalidArgumentException.php',
            'tracker/vendor/sebastian/recursion-context/tests/ContextTest.php',
            'tracker/vendor/sebastian/version/.gitattributes',
            'tracker/vendor/sebastian/version/.gitignore',
            'tracker/vendor/sebastian/version/LICENSE',
            'tracker/vendor/sebastian/version/README.md',
            'tracker/vendor/sebastian/version/composer.json',
            'tracker/vendor/sebastian/version/src/Version.php',
            'tracker/vendor/slim/slim/LICENSE.md',
            'tracker/vendor/slim/slim/MAINTAINERS.md',
            'tracker/vendor/slim/slim/Slim/App.php',
            'tracker/vendor/slim/slim/Slim/CallableResolver.php',
            'tracker/vendor/slim/slim/Slim/CallableResolverAwareTrait.php',
            'tracker/vendor/slim/slim/Slim/Collection.php',
            'tracker/vendor/slim/slim/Slim/Container.php',
            'tracker/vendor/slim/slim/Slim/DefaultServicesProvider.php',
            'tracker/vendor/slim/slim/Slim/DeferredCallable.php',
            'tracker/vendor/slim/slim/Slim/Exception/ContainerException.php',
            'tracker/vendor/slim/slim/Slim/Exception/ContainerValueNotFoundException.php',
            'tracker/vendor/slim/slim/Slim/Exception/InvalidMethodException.php',
            'tracker/vendor/slim/slim/Slim/Exception/MethodNotAllowedException.php',
            'tracker/vendor/slim/slim/Slim/Exception/NotFoundException.php',
            'tracker/vendor/slim/slim/Slim/Exception/SlimException.php',
            'tracker/vendor/slim/slim/Slim/Handlers/AbstractError.php',
            'tracker/vendor/slim/slim/Slim/Handlers/AbstractHandler.php',
            'tracker/vendor/slim/slim/Slim/Handlers/Error.php',
            'tracker/vendor/slim/slim/Slim/Handlers/NotAllowed.php',
            'tracker/vendor/slim/slim/Slim/Handlers/NotFound.php',
            'tracker/vendor/slim/slim/Slim/Handlers/PhpError.php',
            'tracker/vendor/slim/slim/Slim/Handlers/Strategies/RequestResponse.php',
            'tracker/vendor/slim/slim/Slim/Handlers/Strategies/RequestResponseArgs.php',
            'tracker/vendor/slim/slim/Slim/Http/Body.php',
            'tracker/vendor/slim/slim/Slim/Http/Cookies.php',
            'tracker/vendor/slim/slim/Slim/Http/Environment.php',
            'tracker/vendor/slim/slim/Slim/Http/Headers.php',
            'tracker/vendor/slim/slim/Slim/Http/Message.php',
            'tracker/vendor/slim/slim/Slim/Http/NonBufferedBody.php',
            'tracker/vendor/slim/slim/Slim/Http/Request.php',
            'tracker/vendor/slim/slim/Slim/Http/RequestBody.php',
            'tracker/vendor/slim/slim/Slim/Http/Response.php',
            'tracker/vendor/slim/slim/Slim/Http/StatusCode.php',
            'tracker/vendor/slim/slim/Slim/Http/Stream.php',
            'tracker/vendor/slim/slim/Slim/Http/UploadedFile.php',
            'tracker/vendor/slim/slim/Slim/Http/Uri.php',
            'tracker/vendor/slim/slim/Slim/Interfaces/CallableResolverInterface.php',
            'tracker/vendor/slim/slim/Slim/Interfaces/CollectionInterface.php',
            'tracker/vendor/slim/slim/Slim/Interfaces/Http/CookiesInterface.php',
            'tracker/vendor/slim/slim/Slim/Interfaces/Http/EnvironmentInterface.php',
            'tracker/vendor/slim/slim/Slim/Interfaces/Http/HeadersInterface.php',
            'tracker/vendor/slim/slim/Slim/Interfaces/InvocationStrategyInterface.php',
            'tracker/vendor/slim/slim/Slim/Interfaces/RouteGroupInterface.php',
            'tracker/vendor/slim/slim/Slim/Interfaces/RouteInterface.php',
            'tracker/vendor/slim/slim/Slim/Interfaces/RouterInterface.php',
            'tracker/vendor/slim/slim/Slim/MiddlewareAwareTrait.php',
            'tracker/vendor/slim/slim/Slim/Routable.php',
            'tracker/vendor/slim/slim/Slim/Route.php',
            'tracker/vendor/slim/slim/Slim/RouteGroup.php',
            'tracker/vendor/slim/slim/Slim/Router.php',
            'tracker/vendor/slim/slim/composer.json',
            'tracker/vendor/slim/slim/phpstan.neon.dist',
            'tracker/vendor/symfony/polyfill-ctype/Ctype.php',
            'tracker/vendor/symfony/polyfill-ctype/LICENSE',
            'tracker/vendor/symfony/polyfill-ctype/README.md',
            'tracker/vendor/symfony/polyfill-ctype/bootstrap.php',
            'tracker/vendor/symfony/polyfill-ctype/composer.json',
            'tracker/vendor/symfony/yaml/.gitignore',
            'tracker/vendor/symfony/yaml/CHANGELOG.md',
            'tracker/vendor/symfony/yaml/Dumper.php',
            'tracker/vendor/symfony/yaml/Escaper.php',
            'tracker/vendor/symfony/yaml/Exception/DumpException.php',
            'tracker/vendor/symfony/yaml/Exception/ExceptionInterface.php',
            'tracker/vendor/symfony/yaml/Exception/ParseException.php',
            'tracker/vendor/symfony/yaml/Exception/RuntimeException.php',
            'tracker/vendor/symfony/yaml/Inline.php',
            'tracker/vendor/symfony/yaml/LICENSE',
            'tracker/vendor/symfony/yaml/Parser.php',
            'tracker/vendor/symfony/yaml/README.md',
            'tracker/vendor/symfony/yaml/Tests/DumperTest.php',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/YtsAnchorAlias.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/YtsBasicTests.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/YtsBlockMapping.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/YtsDocumentSeparator.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/YtsErrorTests.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/YtsFlowCollections.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/YtsFoldedScalars.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/YtsNullsAndEmpties.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/YtsSpecificationExamples.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/YtsTypeTransfers.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/embededPhp.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/escapedCharacters.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/index.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/sfComments.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/sfCompact.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/sfMergeKey.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/sfObjects.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/sfQuotes.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/sfTests.yml',
            'tracker/vendor/symfony/yaml/Tests/Fixtures/unindentedCollections.yml',
            'tracker/vendor/symfony/yaml/Tests/InlineTest.php',
            'tracker/vendor/symfony/yaml/Tests/ParseExceptionTest.php',
            'tracker/vendor/symfony/yaml/Tests/ParserTest.php',
            'tracker/vendor/symfony/yaml/Tests/YamlTest.php',
            'tracker/vendor/symfony/yaml/Unescaper.php',
            'tracker/vendor/symfony/yaml/Yaml.php',
            'tracker/vendor/symfony/yaml/composer.json',
            'tracker/vendor/symfony/yaml/phpunit.xml.dist',
            'tracker/vendor/vboctor/disposable_email_checker/.gitignore',
            'tracker/vendor/vboctor/disposable_email_checker/.travis.yml',
            'tracker/vendor/vboctor/disposable_email_checker/changelog.txt',
            'tracker/vendor/vboctor/disposable_email_checker/composer.json',
            'tracker/vendor/vboctor/disposable_email_checker/composer.lock',
            'tracker/vendor/vboctor/disposable_email_checker/data/.htaccess',
            'tracker/vendor/vboctor/disposable_email_checker/data/domains.txt',
            'tracker/vendor/vboctor/disposable_email_checker/license.txt',
            'tracker/vendor/vboctor/disposable_email_checker/php/src/DisposableEmailChecker.php',
            'tracker/vendor/vboctor/disposable_email_checker/php/tests/disposable_email_checker_tests.php',
            'tracker/vendor/vboctor/disposable_email_checker/readme.md',
            'tracker/vendor/webmozart/assert/CHANGELOG.md',
            'tracker/vendor/webmozart/assert/LICENSE',
            'tracker/vendor/webmozart/assert/README.md',
            'tracker/vendor/webmozart/assert/composer.json',
            'tracker/vendor/webmozart/assert/src/Assert.php',
            'tracker/verify.php',
            'tracker/view.php',
            'tracker/view_all_bug_page.php',
            'tracker/view_all_inc.php',
            'tracker/view_all_set.php',
            'tracker/view_filters_page.php',
            'tracker/view_user_page.php',
            'tracker/wiki.php',
            'tracker/workflow_graph_img.php',
            'tracker/xmlhttprequest.php',
        ];
    }
}
